@@ -72,10 +72,10 @@ void AttachmentTest::testValidity()
 
 void AttachmentTest::testSerializer_data()
 {
-    QTest::addColumn<KCalCore::Attachment::Ptr>("attachment");
+    QTest::addColumn<KCalCore::Attachment>("attachment");
 
-    Attachment::Ptr nonInline = Attachment::Ptr(new Attachment(QStringLiteral("http://www.kde.org")));
-    Attachment::Ptr inlineAttachment = Attachment::Ptr(new Attachment(QByteArray("foo"), QStringLiteral("image/nonsense")));
+    Attachment nonInline(QStringLiteral("http://www.kde.org"));
+    Attachment inlineAttachment(QByteArray("foo"), QStringLiteral("image/nonsense"));
 
     QTest::newRow("inline") << inlineAttachment;
     QTest::newRow("not inline") << nonInline;
@@ -83,31 +83,15 @@ void AttachmentTest::testSerializer_data()
 
 void AttachmentTest::testSerializer()
 {
-    QFETCH(KCalCore::Attachment::Ptr, attachment);
+    QFETCH(KCalCore::Attachment, attachment);
 
     QByteArray array;
     QDataStream stream(&array, QIODevice::WriteOnly);
     stream << attachment; // Serialize
 
-    Attachment::Ptr attachment2 = Attachment::Ptr(new Attachment(QStringLiteral("foo")));
-    QVERIFY(*attachment != *attachment2);
+    Attachment attachment2(QStringLiteral("foo"));
+    QVERIFY(attachment != attachment2);
     QDataStream stream2(&array, QIODevice::ReadOnly);
     stream2 >> attachment2; // deserialize
-    QVERIFY(*attachment == *attachment2);
-}
-
-void AttachmentTest::testWriteToTempFile()
-{
-    QByteArray data("foo");
-    Attachment::Ptr inlineAttachment = Attachment::Ptr(new Attachment(data.toBase64(), QStringLiteral("image/png")));
-    Event *event = new Event();
-    QString filePath = event->writeAttachmentToTempFile(inlineAttachment);
-    QVERIFY(filePath.endsWith(QLatin1String(".png")));
-    QFile file(filePath);
-    QVERIFY(file.open(QIODevice::ReadOnly | QIODevice::Text));
-    QCOMPARE(file.readLine(), data);
-    file.close();
-
-    delete event; // file is deleted in DTOR
-    QVERIFY(!QFile::exists(filePath));
+    QVERIFY(attachment == attachment2);
 }
