@@ -95,7 +95,7 @@ void ICalFormatTest::testCharsets()
 
     // Test fromRawString()
     MemoryCalendar::Ptr calendar3(new MemoryCalendar(QTimeZone::utc()));
-    format.fromRawString(calendar3, bytesFromFile);
+    QVERIFY(format.fromRawString(calendar3, bytesFromFile));
     QVERIFY(calendar3->incidences().count() == 1);
     QVERIFY(*calendar3->incidences().at(0) == *event);
 
@@ -130,8 +130,8 @@ void ICalFormatTest::testCuType()
     event->setDtEnd(QDateTime(currentDate.addDays(1), {}));
     event->setAllDay(true);
 
-    Attendee::Ptr attendee(new Attendee(QStringLiteral("fred"), QStringLiteral("fred@flintstone.com")));
-    attendee->setCuType(Attendee::Resource);
+    Attendee attendee(QStringLiteral("fred"), QStringLiteral("fred@flintstone.com"));
+    attendee.setCuType(Attendee::Resource);
 
     event->addAttendee(attendee);
 
@@ -145,8 +145,28 @@ void ICalFormatTest::testCuType()
 
     Incidence::Ptr event2 = format.fromString(serializedCalendar);
     QVERIFY(event2->attendeeCount() == 1);
-    Attendee::Ptr attendee2 = event2->attendees()[0];
-    QVERIFY(attendee2->cuType() == attendee->cuType());
-    QVERIFY(attendee2->name() == attendee->name());
-    QVERIFY(attendee2->email() == attendee->email());
+    Attendee attendee2 = event2->attendees()[0];
+    QVERIFY(attendee2.cuType() == attendee.cuType());
+    QVERIFY(attendee2.name() == attendee.name());
+    QVERIFY(attendee2.email() == attendee.email());
+}
+
+void ICalFormatTest::testAlarm()
+{
+    ICalFormat format;
+
+    Event::Ptr event(new Event);
+    event->setDtStart(QDateTime(QDate(2017, 03, 24)));
+    Alarm::Ptr alarm = event->newAlarm();
+    alarm->setType(Alarm::Display);
+    alarm->setStartOffset(Duration(0));
+
+    const QString serialized
+        = QLatin1String("BEGIN:VCALENDAR\nPRODID:-//K Desktop Environment//NONSGML libkcal 3.2//EN\nVERSION:2.0\n")
+        + format.toString(event.staticCast<Incidence>())
+        + QLatin1String("\nEND:VCALENDAR");
+
+    Incidence::Ptr event2 = format.fromString(serialized);
+    Alarm::Ptr alarm2 = event2->alarms()[0];
+    QCOMPARE(*alarm, *alarm2);
 }
