@@ -127,7 +127,7 @@ static bool compareMailAddresses(const Person::List &list1, const Person::List &
 {
     if (list1.count() == list2.count()) {
         for (int i = 0; i < list1.count(); ++i) {
-            if (*list1.at(i) != *list2.at(i)) {
+            if (list1.at(i) != list2.at(i)) {
                 return false;
             }
         }
@@ -198,16 +198,18 @@ void Alarm::setType(Alarm::Type type)
     }
     switch (type) {
     case Display:
-        d->mDescription = QStringLiteral("");
+        d->mDescription.clear();
         break;
     case Procedure:
-        d->mFile = d->mDescription = QStringLiteral("");
+        d->mFile.clear();
+        d->mDescription.clear();
         break;
     case Audio:
-        d->mFile = QStringLiteral("");
+        d->mFile.clear();
         break;
     case Email:
-        d->mMailSubject = d->mDescription = QStringLiteral("");
+        d->mMailSubject.clear();
+        d->mDescription.clear();
         d->mMailAddresses.clear();
         d->mMailAttachFiles.clear();
         break;
@@ -327,7 +329,7 @@ void Alarm::setEmailAlarm(const QString &subject, const QString &text,
     }
 }
 
-void Alarm::setMailAddress(const Person::Ptr &mailAddress)
+void Alarm::setMailAddress(const Person &mailAddress)
 {
     if (d->mType == Email) {
         if (d->mParent) {
@@ -354,7 +356,7 @@ void Alarm::setMailAddresses(const Person::List &mailAddresses)
     }
 }
 
-void Alarm::addMailAddress(const Person::Ptr &mailAddress)
+void Alarm::addMailAddress(const Person &mailAddress)
 {
     if (d->mType == Email) {
         if (d->mParent) {
@@ -836,10 +838,23 @@ int Alarm::locationRadius() const
 QDataStream &KCalCore::operator<<(QDataStream &out, const KCalCore::Alarm::Ptr &a)
 {
     if (a) {
-        out << ((quint32)a->d->mType) << a->d->mAlarmSnoozeTime << a->d->mAlarmRepeatCount << a->d->mEndOffset << a->d->mHasTime
-            << a->d->mAlarmEnabled << a->d->mHasLocationRadius << a->d->mLocationRadius << a->d->mOffset;
+        out << ((quint32)a->d->mType)
+            << a->d->mAlarmSnoozeTime
+            << a->d->mAlarmRepeatCount
+            << a->d->mEndOffset
+            << a->d->mHasTime
+            << a->d->mAlarmEnabled
+            << a->d->mHasLocationRadius
+            << a->d->mLocationRadius
+            << a->d->mOffset;
+
         serializeQDateTimeAsKDateTime(out, a->d->mAlarmTime);
-        out << a->d->mFile << a->d->mMailSubject << a->d->mDescription << a->d->mMailAttachFiles << a->d->mMailAddresses;
+
+        out << a->d->mFile
+            << a->d->mMailSubject
+            << a->d->mDescription
+            << a->d->mMailAttachFiles
+            << a->d->mMailAddresses;
     }
     return out;
 }
