@@ -33,7 +33,7 @@
 
 #include <QHash>
 #include <QString>
-#include <QSharedPointer>
+#include <QSharedDataPointer>
 #include <QMetaType>
 
 namespace KCalCore
@@ -46,12 +46,12 @@ namespace KCalCore
   This is not an email message attachment.
 
   Calendar Incidence attachments consist of:
-  - A <a href="http://en.wikipedia.org/wiki/Uniform_Resource_Identifier">
+  - A <a href="https://en.wikipedia.org/wiki/Uniform_Resource_Identifier">
     Uniform Resource Identifier (URI)</a>
     or a
-    <a href="http://en.wikipedia.org/wiki/Base64#MIME">base64 encoded</a>
+    <a href="https://en.wikipedia.org/wiki/Base64#MIME">base64 encoded</a>
     binary blob.
-  - A <a href="http://en.wikipedia.org/wiki/MIME">
+  - A <a href="https://en.wikipedia.org/wiki/MIME">
     Multipurpose Internet Mail Extensions (MIME)</a> type.
 
   This class is used to associate files (local or remote) or other resources
@@ -59,16 +59,27 @@ namespace KCalCore
 */
 class KCALCORE_EXPORT Attachment
 {
-public:
-    /**
-      A shared pointer to an Attachment object.
-    */
-    typedef QSharedPointer<Attachment> Ptr;
+    Q_GADGET
+    Q_PROPERTY(bool isEmpty READ isEmpty)
+    Q_PROPERTY(QString uri READ uri WRITE setUri)
+    Q_PROPERTY(bool isUri READ isUri)
+    Q_PROPERTY(bool isBinary READ isBinary)
+    Q_PROPERTY(int size READ size)
+    Q_PROPERTY(QString mimeType READ mimeType WRITE setMimeType)
+    Q_PROPERTY(bool showInline READ showInline WRITE setShowInline)
+    Q_PROPERTY(QString label READ label WRITE setLabel)
+    Q_PROPERTY(bool isLocal READ isLocal WRITE setLocal)
 
+public:
     /**
       List of attachments.
     */
-    typedef QVector<Ptr> List;
+    typedef QVector<Attachment> List;
+
+    /**
+      Constructs an empty attachment.
+    */
+    explicit Attachment();
 
     /**
       Constructs an attachment consisting of a @p uri and a @p mime type.
@@ -100,6 +111,11 @@ public:
     */
     ~Attachment();
 
+    /**
+       Returns whether this is an empty or default constructed object.
+    */
+    bool isEmpty() const;
+
     /**
       Sets the @acronym URI for this attachment to @p uri.
 
@@ -114,21 +130,21 @@ public:
 
       @see setUri(), isUri()
     */
-    QString uri() const;
+    Q_REQUIRED_RESULT QString uri() const;
 
     /**
       Returns true if the attachment has a @acronym URI; false otherwise.
 
       @see uri(), setUri(I), isBinary()
     */
-    bool isUri() const;
+    Q_REQUIRED_RESULT bool isUri() const;
 
     /**
       Returns true if the attachment has a binary blob; false otherwise.
 
       @see isUri()
     */
-    bool isBinary() const;
+    Q_REQUIRED_RESULT bool isBinary() const;
 
     /**
       Sets the base64 encoded binary blob data of the attachment.
@@ -145,7 +161,7 @@ public:
 
       @see setData(), setDecodedData()
     */
-    QByteArray data() const;
+    Q_REQUIRED_RESULT QByteArray data() const;
 
     /**
       Sets the decoded attachment data.
@@ -162,7 +178,7 @@ public:
 
       @see setDecodedData(), setData()
     */
-    QByteArray decodedData() const;
+    Q_REQUIRED_RESULT QByteArray decodedData() const;
 
     /**
       Returns the size of the attachment, in bytes.
@@ -185,7 +201,7 @@ public:
 
       @see setMimeType()
     */
-    QString mimeType() const;
+    Q_REQUIRED_RESULT QString mimeType() const;
 
     /**
       Sets the attachment "show in-line" option, which is derived from
@@ -203,7 +219,7 @@ public:
 
       @see setShowInline()
     */
-    bool showInline() const;
+    Q_REQUIRED_RESULT bool showInline() const;
 
     /**
       Sets the attachment label to @p label, which is derived from
@@ -218,7 +234,7 @@ public:
     /**
       Returns the attachment label string.
     */
-    QString label() const;
+    Q_REQUIRED_RESULT QString label() const;
 
     /**
       Sets the attachment "local" option, which is derived from the
@@ -234,7 +250,7 @@ public:
     /**
       Returns the attachment "local" flag.
     */
-    bool isLocal() const;
+    Q_REQUIRED_RESULT bool isLocal() const;
 
     /**
       Assignment operator.
@@ -259,11 +275,11 @@ public:
 private:
     //@cond PRIVATE
     class Private;
-    Private *const d;
+    QSharedDataPointer<Private> d;
     //@endcond
 
-    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KCalCore::Attachment::Ptr &);
-    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &s, const KCalCore::Attachment::Ptr &);
+    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KCalCore::Attachment&);
+    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &s, KCalCore::Attachment&);
 };
 
 /**
@@ -271,27 +287,20 @@ private:
  *
  * @since 4.12
  */
-KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::Attachment::Ptr &);
+KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::Attachment&);
 
 /**
  * Attachment deserializer.
  *
  * @since 4.12
  */
-KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, const KCalCore::Attachment::Ptr &);
+KCALCORE_EXPORT QDataStream &operator>>(QDataStream &in, KCalCore::Attachment&);
 
 }
 
 //@cond PRIVATE
-Q_DECLARE_TYPEINFO(KCalCore::Attachment::Ptr, Q_MOVABLE_TYPE);
-Q_DECLARE_METATYPE(KCalCore::Attachment::Ptr)
-//@endcond
-
-//@cond PRIVATE
-inline uint qHash(const QSharedPointer<KCalCore::Attachment> &key)
-{
-    return qHash<KCalCore::Attachment>(key.data());
-}
+Q_DECLARE_TYPEINFO(KCalCore::Attachment, Q_MOVABLE_TYPE);
+Q_DECLARE_METATYPE(KCalCore::Attachment)
 //@endcond
 
 #endif
