@@ -30,10 +30,10 @@
 #define KCALCORE_ATTENDEE_H
 
 #include <QMetaType>
+#include <QSharedDataPointer>
 
 #include "kcalcore_export.h"
 #include "customproperties.h"
-#include "person.h"
 
 namespace KCalCore
 {
@@ -55,15 +55,22 @@ namespace KCalCore
   (unique identifier) derived from a Calendar Incidence, Email Message,
   or any other thing you want.
 */
-class KCALCORE_EXPORT Attendee : private Person
+class KCALCORE_EXPORT Attendee
 {
-public:
-    using Person::setEmail;
-    using Person::email;
-    using Person::setName;
-    using Person::name;
-    using Person::fullName;
+    Q_GADGET
+    Q_PROPERTY(bool isNull READ isNull)
+    Q_PROPERTY(QString name READ name WRITE setName)
+    Q_PROPERTY(QString fullName READ fullName)
+    Q_PROPERTY(QString email READ email WRITE setEmail)
+    Q_PROPERTY(Role role READ role WRITE setRole)
+    Q_PROPERTY(QString uid READ uid WRITE setUid)
+    Q_PROPERTY(PartStat status READ status WRITE setStatus)
+    Q_PROPERTY(CuType cuType READ cuType WRITE setCuType)
+    Q_PROPERTY(bool rsvp READ RSVP WRITE setRSVP)
+    Q_PROPERTY(QString delegate READ delegate WRITE setDelegate)
+    Q_PROPERTY(QString delegator READ delegator WRITE setDelegator)
 
+public:
     /**
       The different types of participant status.
       The meaning is specific to the incidence type in context.
@@ -78,6 +85,7 @@ public:
         InProcess,       /**< To-do in process of being completed */
         None
     };
+    Q_ENUM(PartStat)
 
     /**
       The different types of participation roles.
@@ -88,6 +96,7 @@ public:
         NonParticipant,  /**< Non-Participant; copied for information purposes */
         Chair            /**< Chairperson */
     };
+    Q_ENUM(Role)
 
     /**
      * The different types of a participant.
@@ -106,19 +115,18 @@ public:
          * iana-token     ; Other IANA-registered
          */
     };
-
-    /**
-      A shared pointer to an Attendee object.
-    */
-    typedef QSharedPointer<Attendee> Ptr;
+    Q_ENUM(CuType)
 
     /**
       List of attendees.
     */
-    typedef QVector<Ptr> List;
+    typedef QVector<Attendee> List;
+
+    /** Create a null Attendee. */
+    Attendee();
 
     /**
-      Constructs an attendee consisting of a Person name (@p name) and
+      Constructs an attendee consisting of a person name (@p name) and
       email address (@p email); invitation status and #Role;
       an optional @acronym RSVP flag and @acronym UID.
 
@@ -145,6 +153,36 @@ public:
     */
     ~Attendee();
 
+    /**
+     * Returns @c true if this is a default-constructed Attendee instance.
+     */
+    bool isNull() const;
+
+    /**
+      Returns the name of the attendee.
+    */
+    Q_REQUIRED_RESULT QString name() const;
+    /**
+      Sets the name of the attendee to @p name.
+    */
+    void setName(const QString &name);
+
+    /**
+      Returns the full name and email address of this attendee
+      @return A QString containing the person's full name in the form
+        "FirstName LastName \<mail@domain\>".
+    */
+    Q_REQUIRED_RESULT QString fullName() const;
+
+    /**
+      Returns the email address for this attendee.
+    */
+    Q_REQUIRED_RESULT QString email() const;
+    /**
+      Sets the email address for this attendee to @p email.
+    */
+    void setEmail(const QString &email);
+
     /**
       Sets the Role of the attendee to @p role.
 
@@ -319,13 +357,13 @@ public:
 private:
     //@cond PRIVATE
     class Private;
-    Private *const d;
+    QSharedDataPointer<Private> d;
     //@endcond
 
     friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &s,
-            const KCalCore::Attendee::Ptr &attendee);
+            const KCalCore::Attendee &attendee);
     friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &s,
-            KCalCore::Attendee::Ptr &attendee);
+            KCalCore::Attendee &attendee);
 };
 
 /**
@@ -334,7 +372,7 @@ private:
   @param attendee is a pointer to a Attendee object to be serialized.
 */
 KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream,
-                                        const KCalCore::Attendee::Ptr &attendee);
+                                        const KCalCore::Attendee &attendee);
 
 /**
   Initializes an Attendee object from a data stream.
@@ -342,12 +380,12 @@ KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream,
   @param attendee is a pointer to a Attendee object to be initialized.
 */
 KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream,
-                                        KCalCore::Attendee::Ptr &attendee);
+                                        KCalCore::Attendee &attendee);
 }
 
 //@cond PRIVATE
-Q_DECLARE_TYPEINFO(KCalCore::Attendee::Ptr, Q_MOVABLE_TYPE);
-Q_DECLARE_METATYPE(KCalCore::Attendee::Ptr)
+Q_DECLARE_TYPEINFO(KCalCore::Attendee, Q_MOVABLE_TYPE);
+Q_DECLARE_METATYPE(KCalCore::Attendee)
 //@endcond
 
 #endif
