@@ -156,14 +156,13 @@ Calendar::~Calendar()
     delete d;
 }
 
-Person::Ptr Calendar::owner() const
+Person Calendar::owner() const
 {
     return d->mOwner;
 }
 
-void Calendar::setOwner(const Person::Ptr &owner)
+void Calendar::setOwner(const Person &owner)
 {
-    Q_ASSERT(owner);
     d->mOwner = owner;
     setModified(true);
 }
@@ -184,7 +183,7 @@ void Calendar::setTimeZoneId(const QByteArray &timeZoneId)
 {
     d->mTimeZone = d->timeZoneIdSpec(timeZoneId);
 
-    doSetTimeZone(d->mTimeZone);
+    doSetTimeZone(d->mTimeZone); //NOLINT false clang-analyzer-optin.cplusplus.VirtualCall
 }
 
 //@cond PRIVATE
@@ -194,8 +193,9 @@ QTimeZone Calendar::Private::timeZoneIdSpec(const QByteArray &timeZoneId)
         return QTimeZone::utc();
     }
     auto tz = QTimeZone(timeZoneId);
-    if (tz.isValid())
+    if (tz.isValid()) {
         return tz;
+    }
     return QTimeZone::systemTimeZone();
 }
 //@endcond
@@ -461,7 +461,6 @@ Event::List Calendar::sortEvents(const Event::List &eventList,
                                  EventSortField sortField,
                                  SortDirection sortDirection)
 {
-
     if (eventList.isEmpty()) {
         return Event::List();
     }
@@ -838,7 +837,9 @@ void Calendar::setupRelations(const Incidence::Ptr &forincidence)
             // look for hierarchy loops
             if (isAncestorOf(forincidence, parent)) {
                 forincidence->setRelatedTo(QString());
-                qCWarning(KCALCORE_LOG) << "hierarchy loop beetween " << forincidence->uid() << " and " << parent->uid();
+                qCWarning(KCALCORE_LOG) << "hierarchy loop between "
+                                        << forincidence->uid()
+                                        << " and " << parent->uid();
             } else {
                 d->mIncidenceRelations[parent->uid()].append(forincidence);
             }
@@ -979,11 +980,6 @@ void Calendar::CalendarObserver::calendarIncidenceAboutToBeDeleted(const Inciden
     Q_UNUSED(incidence);
 }
 
-void Calendar::CalendarObserver::calendarIncidenceDeleted(const Incidence::Ptr &incidence)
-{
-    Q_UNUSED(incidence);
-}
-
 void Calendar::CalendarObserver::calendarIncidenceDeleted(const Incidence::Ptr &incidence, const Calendar *calendar)
 {
     Q_UNUSED(incidence);
@@ -1050,7 +1046,6 @@ bool Calendar::reload()
 
 void Calendar::incidenceUpdated(const QString &uid, const QDateTime &recurrenceId)
 {
-
     Incidence::Ptr inc = incidence(uid, recurrenceId);
 
     if (!inc) {
@@ -1126,21 +1121,6 @@ void Calendar::notifyIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence)
     }
 }
 
-void Calendar::notifyIncidenceDeletedOld(const Incidence::Ptr &incidence)
-{
-    if (!incidence) {
-        return;
-    }
-
-    if (!d->mObserversEnabled) {
-        return;
-    }
-
-    for (CalendarObserver *observer : qAsConst(d->mObservers)) {
-        observer->calendarIncidenceDeleted(incidence);
-    }
-}
-
 void Calendar::notifyIncidenceDeleted(const Incidence::Ptr &incidence)
 {
     if (!incidence) {
