@@ -196,9 +196,9 @@ void CustomProperties::setCustomProperties(const QMap<QByteArray, QString> &prop
         // Validate the property name and convert any null string to empty string
         if (checkName(it.key())) {
             if (d->isVolatileProperty(QLatin1String(it.key()))) {
-                d->mVolatileProperties[it.key()] = it.value().isNull() ? QStringLiteral("") : it.value();
+                d->mVolatileProperties[it.key()] = it.value().isNull() ? QLatin1String("") : it.value();
             } else {
-                d->mProperties[it.key()] = it.value().isNull() ? QStringLiteral("") : it.value();
+                d->mProperties[it.key()] = it.value().isNull() ? QLatin1String("") : it.value();
             }
             if (!changed) {
                 customPropertyUpdate();
