@@ -38,10 +38,27 @@
 
 using namespace KCalCore;
 
-Exception::Exception(const ErrorCode code, const QStringList &arguments)
-    : mCode(code), mArguments(arguments), d(0)
+namespace KCalCore {
+
+class ExceptionPrivate
 {
-    Q_UNUSED(d);
+public:
+    /**
+      The current exception code.
+    */
+    Exception::ErrorCode mCode;
+
+    /** Arguments to pass to i18n(). */
+    QStringList mArguments;
+};
+
+}
+
+Exception::Exception(const ErrorCode code, const QStringList &arguments)
+    : d(new ExceptionPrivate)
+{
+    d->mCode = code;
+    d->mArguments = arguments;
 }
 
 Exception::~Exception()
@@ -50,20 +67,10 @@ Exception::~Exception()
 
 Exception::ErrorCode Exception::code() const
 {
-    return mCode;
+    return d->mCode;
 }
 
 QStringList Exception::arguments() const
 {
-    return mArguments;
+    return d->mArguments;
 }
-
-/**
-  Private class that helps to provide binary compatibility between releases.
-  @internal
-*/
-//@cond PRIVATE
-class Q_DECL_HIDDEN KCalCore::Exception::Private
-{
-};
-//@endcond
