@@ -129,9 +129,9 @@ public:
     icalproperty *writeDescription(const QString &description, bool isRich = false);
     icalproperty *writeSummary(const QString &summary, bool isRich = false);
     icalproperty *writeLocation(const QString &location, bool isRich = false);
-    icalproperty *writeAttendee(const Attendee::Ptr &attendee);
-    icalproperty *writeOrganizer(const Person::Ptr &organizer);
-    icalproperty *writeAttachment(const Attachment::Ptr &attach);
+    icalproperty *writeAttendee(const Attendee &attendee);
+    icalproperty *writeOrganizer(const Person &organizer);
+    icalproperty *writeAttachment(const Attachment &attach);
     icalproperty *writeRecurrenceRule(Recurrence *);
     icalrecurrencetype writeRecurrenceRule(RecurrenceRule *recur);
     icalcomponent *writeAlarm(const Alarm::Ptr &alarm);
@@ -141,9 +141,9 @@ public:
     Event::Ptr readEvent(icalcomponent *vevent, const ICalTimeZoneCache *tzList);
     FreeBusy::Ptr readFreeBusy(icalcomponent *vfreebusy);
     Journal::Ptr readJournal(icalcomponent *vjournal, const ICalTimeZoneCache *tzList);
-    Attendee::Ptr readAttendee(icalproperty *attendee);
-    Person::Ptr readOrganizer(icalproperty *organizer);
-    Attachment::Ptr readAttachment(icalproperty *attach);
+    Attendee readAttendee(icalproperty *attendee);
+    Person readOrganizer(icalproperty *organizer);
+    Attachment readAttachment(icalproperty *attach);
     void readIncidence(icalcomponent *parent, const Incidence::Ptr &incidence, const ICalTimeZoneCache *tzList);
     void readRecurrenceRule(icalproperty *rrule, const Incidence::Ptr &event);
     void readExceptionRule(icalproperty *rrule, const Incidence::Ptr &incidence);
