@@ -24,6 +24,7 @@
 #include "icalformat_p.h"
 #include "recurrence.h"
 #include "recurrencerule.h"
+#include "recurrencehelper_p.h"
 #include "utils.h"
 
 #include "kcalcore_debug.h"
@@ -191,7 +192,6 @@ void ICalTimeZoneParser::updateTzEarliestDate(const IncidenceBase::Ptr &incidenc
     }
 }
 
-
 icalcomponent *ICalTimeZoneParser::icalcomponentFromQTimeZone(const QTimeZone &tz,
                                                               const QDateTime &earliest)
 {
@@ -246,7 +246,7 @@ icalcomponent *ICalTimeZoneParser::icalcomponentFromQTimeZone(const QTimeZone &t
         }
         // Found a phase combination which hasn't yet been processed
         const int preOffset = (i > 0) ? transits.at(i - 1).offsetFromUtc : 0;
-        const auto transit = transits.at(i);
+        const auto &transit = transits.at(i);
         if (transit.offsetFromUtc == preOffset) {
             transitionsDone[i] = true;
             while (++i < trcount) {
@@ -551,11 +551,11 @@ ICalTimeZone ICalTimeZoneParser::parseTimeZone(icalcomponent *vtimezone)
         switch (kind) {
         case ICAL_XSTANDARD_COMPONENT:
             //qCDebug(KCALCORE_LOG) << "---standard phase: found";
-            parsePhase(c, icalTz.standard);
+            parsePhase(c, false, icalTz.standard);
             break;
         case ICAL_XDAYLIGHT_COMPONENT:
             //qCDebug(KCALCORE_LOG) << "---daylight phase: found";
-            parsePhase(c, icalTz.daylight);
+            parsePhase(c, true, icalTz.daylight);
             break;
 
         default:
@@ -567,7 +567,7 @@ ICalTimeZone ICalTimeZoneParser::parseTimeZone(icalcomponent *vtimezone)
     return icalTz;
 }
 
-bool ICalTimeZoneParser::parsePhase(icalcomponent *c, ICalTimeZonePhase &phase)
+bool ICalTimeZoneParser::parsePhase(icalcomponent *c, bool daylight, ICalTimeZonePhase &phase)
 {
     // Read the observance data for this standard/daylight savings phase
     int utcOffset = 0;
@@ -651,7 +651,6 @@ bool ICalTimeZoneParser::parsePhase(icalcomponent *c, ICalTimeZonePhase &phase)
          * Note that we had to get DTSTART, TZOFFSETFROM, TZOFFSETTO before reading
          * recurrences.
          */
-        const QDateTime klocalStart(localStart);
         const QDateTime maxTime(MAX_DATE());
         Recurrence recur;
         icalproperty *p = icalcomponent_get_first_property(c, ICAL_ANY_PROPERTY);
@@ -694,7 +693,7 @@ bool ICalTimeZoneParser::parsePhase(icalcomponent *c, ICalTimeZonePhase &phase)
                 ICalFormat icf;
                 ICalFormatImpl impl(&icf);
                 impl.readRecurrence(icalproperty_get_rrule(p), &r);
-                r.setStartDt(klocalStart);
+                r.setStartDt(localStart);
                 // The end date time specified in an RRULE should be in UTC.
                 // Convert to local time to avoid timesInInterval() getting things wrong.
                 if (r.duration() == 0) {
@@ -704,7 +703,7 @@ bool ICalTimeZoneParser::parsePhase(icalcomponent *c, ICalTimeZonePhase &phase)
                         r.setEndDt(end.addSecs(prevOffset));
                     }
                 }
-                const auto dts = r.timesInInterval(klocalStart, maxTime);
+                const auto dts = r.timesInInterval(localStart, maxTime);
                 for (int i = 0, end = dts.count();  i < end;  ++i) {
                     QDateTime utc = dts[i];
                     utc.setTimeSpec(Qt::UTC);
@@ -717,7 +716,7 @@ bool ICalTimeZoneParser::parsePhase(icalcomponent *c, ICalTimeZonePhase &phase)
             }
             p = icalcomponent_get_next_property(c, ICAL_ANY_PROPERTY);
         }
-        qSortUnique(phase.transitions);
+        sortAndRemoveDuplicates(phase.transitions);
     }
 
     return true;
