@@ -36,13 +36,10 @@
 #include "calformat.h"
 #include "utils.h"
 
-#include <QTemporaryFile>
-#include <QMimeDatabase>
 #include <QTextDocument> // for .toHtmlEscaped() and Qt::mightBeRichText()
 #include <QStringList>
 #include <QTime>
 #include <QTimeZone>
-#include <QDebug>
 
 using namespace KCalCore;
 
@@ -137,12 +134,7 @@ public:
             mAlarms.append(b);
         }
 
-        mAttachments.reserve(src.d->mAttachments.count());
-        for (const Attachment::Ptr &attachment : qAsConst(src.d->mAttachments)) {
-            Attachment::Ptr a(new Attachment(*attachment));
-            mAttachments.append(a);
-        }
-
+        mAttachments = src.d->mAttachments;
         if (src.d->mRecurrence) {
             mRecurrence = new Recurrence(*(src.d->mRecurrence));
             mRecurrence->addObserver(dest);
@@ -162,7 +154,6 @@ public:
     QString mStatusString;              // status string, for custom status
     QString mSchedulingID;              // ID for scheduling mails
     QMap<RelType, QString> mRelatedToUid; // incidence uid this is related to, for each relType
-    QHash<Attachment::Ptr, QString> mTempFiles; // Temporary files for writing attachments to.
     QDateTime mRecurrenceId;            // recurrenceId
 
     float mGeoLatitude;                 // Specifies latitude in decimal degrees
@@ -205,7 +196,6 @@ Incidence::~Incidence()
     for (const Alarm::Ptr &alarm : qAsConst(d->mAlarms)) {
         alarm->setParent(nullptr);
     }
-    clearTempFiles();
     delete d->mRecurrence;
     delete d;
 }
@@ -269,7 +259,7 @@ bool Incidence::equals(const IncidenceBase &incidence) const
     Attachment::List::ConstIterator att2 = otherAttachmentList.constBegin();
     const Attachment::List::ConstIterator att2end = otherAttachmentList.constEnd();
     for (; att1 != att1end && att2 != att2end; ++att1, ++att2) {
-        if (**att1 == **att2) {
+        if (*att1 == *att2) {
             continue;
         } else {
             return false;
@@ -280,13 +270,14 @@ bool Incidence::equals(const IncidenceBase &incidence) const
     if (!recurrenceEqual) {
         recurrence(); // create if doesn't exist
         i2->recurrence(); // create if doesn't exist
-        recurrenceEqual = d->mRecurrence != nullptr
-                          && i2->d->mRecurrence != nullptr
-                          && *d->mRecurrence == *i2->d->mRecurrence;
+        recurrenceEqual = d->mRecurrence != nullptr &&
+                          i2->d->mRecurrence != nullptr &&
+                          *d->mRecurrence == *i2->d->mRecurrence;
     }
 
     if (d->mHasGeo == i2->d->mHasGeo) {
-        if (d->mHasGeo && (!qFuzzyCompare(d->mGeoLatitude, i2->d->mGeoLatitude) || !qFuzzyCompare(d->mGeoLongitude, i2->d->mGeoLongitude))) {
+        if (d->mHasGeo && (!qFuzzyCompare(d->mGeoLatitude, i2->d->mGeoLatitude) ||
+          !qFuzzyCompare(d->mGeoLongitude, i2->d->mGeoLongitude))) {
             return false;
         }
     } else {
@@ -302,8 +293,7 @@ bool Incidence::equals(const IncidenceBase &incidence) const
         && stringCompare(relatedTo(), i2->relatedTo())
         && resources() == i2->resources()
         && d->mStatus == i2->d->mStatus
-        && (d->mStatus == StatusNone
-            || stringCompare(d->mStatusString, i2->d->mStatusString))
+        && (d->mStatus == StatusNone || stringCompare(d->mStatusString, i2->d->mStatusString))
         && secrecy() == i2->secrecy()
         && priority() == i2->priority()
         && stringCompare(location(), i2->location())
@@ -327,7 +317,7 @@ void Incidence::recreate()
 
     setSchedulingID(QString(), CalFormat::createUniqueId());
     setRevision(0);
-    setLastModified(nowUTC);
+    setLastModified(nowUTC); //NOLINT false clang-analyzer-optin.cplusplus.VirtualCall
 }
 
 void Incidence::setLastModified(const QDateTime &lm)
@@ -708,35 +698,24 @@ QDateTime Incidence::endDateForStart(const QDateTime &startDt) const
     return startDt.addSecs(start.secsTo(end));
 }
 
-void Incidence::addAttachment(const Attachment::Ptr &attachment)
+void Incidence::addAttachment(const Attachment &attachment)
 {
-    if (mReadOnly || !attachment) {
+    if (mReadOnly || attachment.isEmpty()) {
         return;
     }
 
-    Q_ASSERT(!d->mAttachments.contains(attachment));
-
     update();
     d->mAttachments.append(attachment);
     setFieldDirty(FieldAttachment);
     updated();
 }
 
-void Incidence::deleteAttachment(const Attachment::Ptr &attachment)
-{
-    int index = d->mAttachments.indexOf(attachment);
-    if (index > -1) {
-        setFieldDirty(FieldAttachment);
-        d->mAttachments.remove(index);
-    }
-}
-
 void Incidence::deleteAttachments(const QString &mime)
 {
     Attachment::List result;
     Attachment::List::Iterator it = d->mAttachments.begin();
     while (it != d->mAttachments.end()) {
-        if ((*it)->mimeType() != mime) {
+        if ((*it).mimeType() != mime) {
             result += *it;
         }
         ++it;
@@ -753,8 +732,8 @@ Attachment::List Incidence::attachments() const
 Attachment::List Incidence::attachments(const QString &mime) const
 {
     Attachment::List attachments;
-    for (const Attachment::Ptr &attachment : qAsConst(d->mAttachments)) {
-        if (attachment->mimeType() == mime) {
+    for (const Attachment &attachment : qAsConst(d->mAttachments)) {
+        if (attachment.mimeType() == mime) {
             attachments.append(attachment);
         }
     }
@@ -767,43 +746,6 @@ void Incidence::clearAttachments()
     d->mAttachments.clear();
 }
 
-QString Incidence::writeAttachmentToTempFile(const Attachment::Ptr &attachment) const
-{
-    const QString attachementPath = d->mTempFiles.value(attachment);
-    if (!attachementPath.isEmpty()) {
-        return attachementPath;
-    }
-    QTemporaryFile file;
-
-    QMimeDatabase mimeDb;
-    QStringList patterns = mimeDb.mimeTypeForName(attachment->mimeType()).globPatterns();
-
-    if (!patterns.empty()) {
-        file.setFileTemplate(file.fileTemplate() + QString(patterns.first()).remove(QLatin1Char('*')));
-    }
-    file.setAutoRemove(false);
-    file.open();
-    // read-only not to give the idea that it could be written to
-    file.setPermissions(QFile::ReadUser);
-    file.write(QByteArray::fromBase64(attachment->data()));
-    d->mTempFiles.insert(attachment, file.fileName());
-    file.close();
-    return d->mTempFiles.value(attachment);
-}
-
-void Incidence::clearTempFiles()
-{
-    QHash<Attachment::Ptr, QString>::const_iterator it = d->mTempFiles.constBegin();
-    const QHash<Attachment::Ptr, QString>::const_iterator end = d->mTempFiles.constEnd();
-    for (; it != end; ++it) {
-        QFile f(it.value());
-        // On Windows the file must be writeable before we can remove it
-        f.setPermissions(QFile::WriteUser);
-        f.remove();
-    }
-    d->mTempFiles.clear();
-}
-
 void Incidence::setResources(const QStringList &resources)
 {
     if (mReadOnly) {
@@ -1141,7 +1083,7 @@ QStringList Incidence::mimeTypes()
                          << KCalCore::Journal::journalMimeType();
 }
 
-void Incidence::serialize(QDataStream &out)
+void Incidence::serialize(QDataStream &out) const
 {
     serializeQDateTimeAsKDateTime(out, d->mCreated);
     out << d->mRevision << d->mDescription << d->mDescriptionIsRich << d->mSummary
@@ -1157,7 +1099,7 @@ void Incidence::serialize(QDataStream &out)
         out << d->mRecurrence;
     }
 
-    for (const Attachment::Ptr &attachment : qAsConst(d->mAttachments)) {
+    for (const Attachment &attachment : qAsConst(d->mAttachments)) {
         out << attachment;
     }
 
@@ -1193,7 +1135,7 @@ void Incidence::deserialize(QDataStream &in)
 
     d->mAttachments.reserve(attachmentCount);
     for (int i = 0; i < attachmentCount; ++i) {
-        Attachment::Ptr attachment = Attachment::Ptr(new Attachment(QString()));
+        Attachment attachment;
         in >> attachment;
         d->mAttachments.append(attachment);
     }
@@ -1215,3 +1157,11 @@ void Incidence::deserialize(QDataStream &in)
         d->mRelatedToUid.insert(static_cast<Incidence::RelType>(it.key()), it.value());
     }
 }
+
+QVariantList Incidence::attachmentsVariant() const
+{
+    QVariantList l;
+    l.reserve(d->mAttachments.size());
+    std::transform(d->mAttachments.begin(), d->mAttachments.end(), std::back_inserter(l), [](const Attachment &att) { return QVariant::fromValue(att); });
+    return l;
+}
