@@ -77,6 +77,8 @@ class KCALCORE_EXPORT Incidence
     Q_PROPERTY(int priority READ priority WRITE setPriority)
     Q_PROPERTY(QDateTime created READ created WRITE setCreated)
     Q_PROPERTY(KCalCore::Incidence::Secrecy secrecy READ secrecy WRITE setSecrecy)
+    Q_PROPERTY(KCalCore::Incidence::Status status READ status WRITE setStatus)
+    Q_PROPERTY(QVariantList attachments READ attachmentsVariant)
 public:
 
     /**
@@ -95,6 +97,7 @@ public:
         StatusFinal,          /**< journal is final */
         StatusX               /**< a non-standard status string */
     };
+    Q_ENUM(Status)
 
     /**
       The different types of incidence access classifications.
@@ -368,7 +371,7 @@ public:
 
     /**
       Returns the incidence categories as a list of strings.
-      @see setCategories( const QStringList &), setCategories( Const QString &).
+      @see setCategories( const QStringList &), setCategories( const QString &).
     */
     Q_REQUIRED_RESULT QStringList categories() const;
 
@@ -506,19 +509,9 @@ public:
     /**
       Adds an attachment to the incidence.
 
-      @param attachment is a pointer to a valid Attachment object.
-      @see deleteAttachment().
+      @param attachment a valid Attachment object.
     */
-    void addAttachment(const Attachment::Ptr &attachment);
-
-    /**
-      Removes the specified attachment from the incidence.  Additionally,
-      the memory used by the attachment is freed.
-
-      @param attachment is a pointer to a valid Attachment object.
-      @see addAttachment(), deleteAttachments().
-    */
-    void deleteAttachment(const Attachment::Ptr &attachment);
+    void addAttachment(const Attachment &attachment);
 
     /**
       Removes all attachments of the specified MIME type from the incidence.
@@ -545,26 +538,10 @@ public:
 
     /**
       Removes all attachments and frees the memory used by them.
-      @see deleteAttachment( Attachment::Ptr), deleteAttachments( const QString &).
+      @see deleteAttachments( const QString &).
     */
     void clearAttachments();
 
-    /**
-      Writes the data in the attachment @p attachment to a temporary file
-      and returns the local name of the temporary file.
-
-      @param attachment is a pointer to a valid Attachment instance.
-      @return a string containing the name of the temporary file containing the attachment.
-      @see clearTempFiles().
-    */
-    Q_REQUIRED_RESULT QString writeAttachmentToTempFile(const Attachment::Ptr &attachment) const;
-
-    /**
-      Deletes all temporary files used by attachments and frees any memory in use by them.
-      @see writeAttachmentToTempFile().
-    */
-    void clearTempFiles();
-
 // %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 // %%%%%  Secrecy and Status methods
 // %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -862,8 +839,8 @@ protected:
     */
     IncidenceBase &assign(const IncidenceBase &other) override;
 
-    void serialize(QDataStream &out);
-    void deserialize(QDataStream &in);
+    void serialize(QDataStream &out) const override;
+    void deserialize(QDataStream &in) override;
 
 private:
     /**
@@ -874,6 +851,8 @@ private:
      */
     Incidence &operator=(const Incidence &other);
 
+    Q_DECL_HIDDEN QVariantList attachmentsVariant() const;
+
     //@cond PRIVATE
     class Private;
     Private *const d;
