@@ -59,8 +59,7 @@ class Q_DECL_HIDDEN KCalCore::IncidenceBase::Private
 {
 public:
     Private()
-        : mOrganizer(nullptr)
-        , mUpdateGroupLevel(0)
+        : mUpdateGroupLevel(0)
         , mUpdatedPending(false)
         , mAllDay(false)
         , mHasDuration(false)
@@ -84,7 +83,7 @@ public:
 
     QDateTime mLastModified;     // incidence last modified date
     QDateTime mDtStart;          // incidence start time
-    Person::Ptr mOrganizer;           // incidence person (owner)
+    Person mOrganizer;           // incidence person (owner)
     QString mUid;                // incidence unique id
     Duration mDuration;          // incidence duration
     int mUpdateGroupLevel;       // if non-zero, suppresses update() calls
@@ -113,11 +112,8 @@ void IncidenceBase::Private::init(const Private &other)
     mComments = other.mComments;
     mContacts = other.mContacts;
 
-    mAttendees.clear();
+    mAttendees = other.mAttendees;
     mAttendees.reserve(other.mAttendees.count());
-    for (Attendee::List::ConstIterator it = other.mAttendees.constBegin(), end = other.mAttendees.constEnd(); it != end; ++it) {
-        mAttendees.append(Attendee::Ptr(new Attendee(*(*it))));
-    }
     mUrl = other.mUrl;
 }
 
@@ -193,7 +189,7 @@ bool IncidenceBase::equals(const IncidenceBase &i2) const
     //TODO Does the order of attendees in the list really matter?
     //Please delete this comment if you know it's ok, kthx
     for (; a1 != al1.constEnd() && a2 != al2.constEnd(); ++a1, ++a2) {
-        if (!(**a1 == **a2)) {
+        if (!(*a1 == *a2)) {
             // qCDebug(KCALCORE_LOG) << "Attendees are different";
             return false;
         }
@@ -209,7 +205,7 @@ bool IncidenceBase::equals(const IncidenceBase &i2) const
     // no need to compare mObserver
 
     bool a = ((dtStart() == i2.dtStart()) || (!dtStart().isValid() && !i2.dtStart().isValid()));
-    bool b = *(organizer().data()) == *(i2.organizer().data());
+    bool b = organizer() == i2.organizer();
     bool c = uid() == i2.uid();
     bool d = allDay() == i2.allDay();
     bool e = duration() == i2.duration();
@@ -263,19 +259,17 @@ QDateTime IncidenceBase::lastModified() const
     return d->mLastModified;
 }
 
-void IncidenceBase::setOrganizer(const Person::Ptr &organizer)
+void IncidenceBase::setOrganizer(const Person &organizer)
 {
-    if (organizer) {
-        update();
-        // we don't check for readonly here, because it is
-        // possible that by setting the organizer we are changing
-        // the event's readonly status...
-        d->mOrganizer = organizer;
+    update();
+    // we don't check for readonly here, because it is
+    // possible that by setting the organizer we are changing
+    // the event's readonly status...
+    d->mOrganizer = organizer;
 
-        d->mDirtyFields.insert(FieldOrganizer);
+    d->mDirtyFields.insert(FieldOrganizer);
 
-        updated();
-    }
+    updated();
 }
 
 void IncidenceBase::setOrganizer(const QString &o)
@@ -286,16 +280,12 @@ void IncidenceBase::setOrganizer(const QString &o)
     }
 
     // split the string into full name plus email.
-    const Person::Ptr organizer = Person::fromFullName(mail);
+    const Person organizer = Person::fromFullName(mail);
     setOrganizer(organizer);
 }
 
-Person::Ptr IncidenceBase::organizer() const
+Person IncidenceBase::organizer() const
 {
-    if (!d->mOrganizer) {
-        d->mOrganizer = Person::Ptr(new Person());    // init at first use only to save memory
-    }
-
     return d->mOrganizer;
 }
 
@@ -431,32 +421,16 @@ QStringList IncidenceBase::contacts() const
     return d->mContacts;
 }
 
-void IncidenceBase::addAttendee(const Attendee::Ptr &a, bool doupdate)
+void IncidenceBase::addAttendee(const Attendee &a, bool doupdate)
 {
-    if (!a || mReadOnly) {
+    if (a.isNull() || mReadOnly) {
         return;
     }
-
-    Q_ASSERT(!d->mAttendees.contains(a));
+    Q_ASSERT(!a.uid().isEmpty());
 
     if (doupdate) {
         update();
     }
-    if (a->name().left(7).toUpper() == QLatin1String("MAILTO:")) {
-        a->setName(a->name().remove(0, 7));
-    }
-
-    /* If Uid is empty, just use the pointer to Attendee (encoded to
-     * string) as Uid. Only thing that matters is that the Uid is unique
-     * insofar IncidenceBase is concerned, and this does that (albeit
-     * not very nicely). If these are ever saved to disk, should use
-     * (considerably more expensive) CalFormat::createUniqueId(). As Uid
-     * is not part of Attendee in iCal std, it's fairly safe bet that
-     * these will never hit disc though so faster generation speed is
-     * more important than actually being forever unique.*/
-    if (a->uid().isEmpty()) {
-        a->setUid(QString::number((qlonglong)a.data()));
-    }
 
     d->mAttendees.append(a);
     if (doupdate) {
@@ -465,27 +439,6 @@ void IncidenceBase::addAttendee(const Attendee::Ptr &a, bool doupdate)
     }
 }
 
-void IncidenceBase::deleteAttendee(const Attendee::Ptr &a, bool doupdate)
-{
-    if (!a || mReadOnly) {
-        return;
-    }
-
-    int index = d->mAttendees.indexOf(a);
-    if (index >= 0) {
-        if (doupdate) {
-            update();
-        }
-
-        d->mAttendees.remove(index);
-
-        if (doupdate) {
-            d->mDirtyFields.insert(FieldAttendees);
-            updated();
-        }
-    }
-}
-
 Attendee::List IncidenceBase::attendees() const
 {
     return d->mAttendees;
@@ -496,6 +449,29 @@ int IncidenceBase::attendeeCount() const
     return d->mAttendees.count();
 }
 
+void IncidenceBase::setAttendees(const Attendee::List &attendees, bool doUpdate)
+{
+    if (mReadOnly) {
+        return;
+    }
+
+    if (doUpdate) {
+        update();
+    }
+
+    // don't simply assign, we need the logic in addAttendee here too
+    clearAttendees();
+    d->mAttendees.reserve(attendees.size());
+    for (const auto &a : attendees) {
+        addAttendee(a, false);
+    }
+
+    if (doUpdate) {
+        d->mDirtyFields.insert(FieldAttendees);
+        updated();
+    }
+}
+
 void IncidenceBase::clearAttendees()
 {
     if (mReadOnly) {
@@ -505,19 +481,19 @@ void IncidenceBase::clearAttendees()
     d->mAttendees.clear();
 }
 
-Attendee::Ptr IncidenceBase::attendeeByMail(const QString &email) const
+Attendee IncidenceBase::attendeeByMail(const QString &email) const
 {
     Attendee::List::ConstIterator it;
     for (it = d->mAttendees.constBegin(); it != d->mAttendees.constEnd(); ++it) {
-        if ((*it)->email() == email) {
+        if ((*it).email() == email) {
             return *it;
         }
     }
 
-    return Attendee::Ptr();
+    return {};
 }
 
-Attendee::Ptr IncidenceBase::attendeeByMails(const QStringList &emails, const QString &email) const
+Attendee IncidenceBase::attendeeByMails(const QStringList &emails, const QString &email) const
 {
     QStringList mails = emails;
     if (!email.isEmpty()) {
@@ -527,25 +503,25 @@ Attendee::Ptr IncidenceBase::attendeeByMails(const QStringList &emails, const QS
     Attendee::List::ConstIterator itA;
     for (itA = d->mAttendees.constBegin(); itA != d->mAttendees.constEnd(); ++itA) {
         for (QStringList::const_iterator it = mails.constBegin(); it != mails.constEnd(); ++it) {
-            if ((*itA)->email() == (*it)) {
+            if ((*itA).email() == (*it)) {
                 return *itA;
             }
         }
     }
 
-    return Attendee::Ptr();
+    return {};
 }
 
-Attendee::Ptr IncidenceBase::attendeeByUid(const QString &uid) const
+Attendee IncidenceBase::attendeeByUid(const QString &uid) const
 {
     Attendee::List::ConstIterator it;
     for (it = d->mAttendees.constBegin(); it != d->mAttendees.constEnd(); ++it) {
-        if ((*it)->uid() == uid) {
+        if ((*it).uid() == uid) {
             return *it;
         }
     }
 
-    return Attendee::Ptr();
+    return {};
 }
 
 void IncidenceBase::setDuration(const Duration &duration)
@@ -674,6 +650,16 @@ void IncidenceBase::setDirtyFields(const QSet<IncidenceBase::Field> &dirtyFields
     d->mDirtyFields = dirtyFields;
 }
 
+void IncidenceBase::serialize(QDataStream &out) const
+{
+    Q_UNUSED(out);
+}
+
+void IncidenceBase::deserialize(QDataStream &in)
+{
+    Q_UNUSED(in);
+}
+
 /** static */
 quint32 IncidenceBase::magicSerializationIdentifier()
 {
@@ -697,12 +683,12 @@ QDataStream &KCalCore::operator<<(QDataStream &out, const KCalCore::IncidenceBas
         << i->d->mAllDay << i->d->mHasDuration << i->d->mComments << i->d->mContacts
         << i->d->mAttendees.count() << i->d->mUrl;
 
-    for (const Attendee::Ptr &attendee : qAsConst(i->d->mAttendees)) {
+    for (const Attendee &attendee : qAsConst(i->d->mAttendees)) {
         out << attendee;
     }
 
-    // Serialize the sub-class data. In KDE5 we can add new virtuals.
-    i->virtual_hook(KCalCore::IncidenceBase::SerializerHook, &out);
+    // Serialize the sub-class data.
+    i->serialize(out);
 
     return out;
 }
@@ -742,13 +728,13 @@ QDataStream &KCalCore::operator>>(QDataStream &in, KCalCore::IncidenceBase::Ptr
     i->d->mAttendees.clear();
     i->d->mAttendees.reserve(attendeeCount);
     for (int it = 0; it < attendeeCount; it++) {
-        Attendee::Ptr attendee = Attendee::Ptr(new Attendee(QString(), QString()));
+        Attendee attendee;
         in >> attendee;
         i->d->mAttendees.append(attendee);
     }
 
-    // Deserialize the sub-class data. In KDE5 we can add new virtuals.
-    i->virtual_hook(KCalCore::IncidenceBase::DeserializerHook, &in);
+    // Deserialize the sub-class data.
+    i->deserialize(in);
 
     return in;
 }
@@ -756,3 +742,11 @@ QDataStream &KCalCore::operator>>(QDataStream &in, KCalCore::IncidenceBase::Ptr
 IncidenceBase::IncidenceObserver::~IncidenceObserver()
 {
 }
+
+QVariantList IncidenceBase::attendeesVariant() const
+{
+    QVariantList l;
+    l.reserve(d->mAttendees.size());
+    std::transform(d->mAttendees.begin(), d->mAttendees.end(), std::back_inserter(l), [](const Attendee &a) { return QVariant::fromValue(a); });
+    return l;
+}
