@@ -59,10 +59,10 @@
 #include "attendee.h"
 #include "customproperties.h"
 #include "duration.h"
-#include "sortablelist.h"
+#include "person.h"
 
 #include <QDateTime>
-
+#include <QSharedPointer>
 #include <QSet>
 #include <QUrl>
 #include <QDataStream>
@@ -73,10 +73,10 @@ class QTimeZone;
 
 namespace KCalCore {
 /** List of dates */
-typedef SortableList<QDate> DateList;
+typedef QList<QDate> DateList;
 
 /** List of times */
-typedef SortableList<QDateTime> DateTimeList;
+typedef QList<QDateTime> DateTimeList;
 
 class Event;
 class Todo;
@@ -113,6 +113,9 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
     Q_PROPERTY(QDateTime lastModified READ lastModified WRITE setLastModified)
     Q_PROPERTY(QDateTime dtStart READ dtStart WRITE setDtStart)
     Q_PROPERTY(bool allDay READ allDay WRITE setAllDay)
+    Q_PROPERTY(KCalCore::Person organizer READ organizer WRITE setOrganizer)
+    Q_PROPERTY(QVariantList attendees READ attendeesVariant)
+
 public:
     /**
       A shared pointer to an IncidenceBase.
@@ -333,7 +336,7 @@ public:
       @param organizer is a non-null Person to use as the incidence @ref organizer.
       @see organizer(), setOrganizer(const QString &)
     */
-    void setOrganizer(const Person::Ptr &organizer);
+    void setOrganizer(const Person &organizer);
 
     /**
       Sets the incidence organizer to any string @p organizer.
@@ -349,7 +352,7 @@ public:
       is returned.
       @see setOrganizer(const QString &), setOrganizer(const Person &)
     */
-    Person::Ptr organizer() const;
+    Person organizer() const;
 
     /**
       Sets readonly status.
@@ -502,13 +505,12 @@ public:
     Q_REQUIRED_RESULT QStringList contacts() const;
 
     /**
-      Add Attendee to this incidence. IncidenceBase takes ownership of the
-      Attendee object.
+      Add Attendee to this incidence.
 
-      @param attendee a pointer to the attendee to add
+      @param attendee the attendee to add
       @param doUpdate If true the Observers are notified, if false they are not.
     */
-    void addAttendee(const Attendee::Ptr &attendee, bool doUpdate = true);
+    void addAttendee(const Attendee &attendee, bool doUpdate = true);
 
     /**
       Removes all attendees from the incidence.
@@ -516,14 +518,13 @@ public:
     void clearAttendees();
 
     /**
-     Delete single attendee from the incidence.
+       Set the attendees of this incidence.
+       This replaces all previously set attendees, unlike addAttendee.
 
-     The given attendee will be delete()d at the end of this call.
-
-     @param attendee The attendee to be removeComment
-     @param doUpdate If true the Observers are notified, if false they are not.
+       @param attendees A list of attendees.
+       @param doUpdate If true the Observers are notified, if false they are not.
     */
-    void deleteAttendee(const Attendee::Ptr &attendee, bool doUpdate = true);
+    void setAttendees(const Attendee::List &attendees, bool doUpdate = true);
 
     /**
       Returns a list of incidence attendees.
@@ -543,7 +544,7 @@ public:
       form "FirstName LastName <emailaddress>".
       @see attendeeByMails(), attendeesByUid().
     */
-    Attendee::Ptr attendeeByMail(const QString &email) const;
+    Attendee attendeeByMail(const QString &email) const;
 
     /**
       Returns the first incidence attendee with one of the specified
@@ -555,7 +556,7 @@ public:
       in addition to the list specified in @p emails.
       @see attendeeByMail(), attendeesByUid().
     */
-    Attendee::Ptr attendeeByMails(const QStringList &emails, const QString &email = QString()) const;
+    Attendee attendeeByMails(const QStringList &emails, const QString &email = QString()) const;
 
     /**
       Returns the incidence attendee with the specified attendee @acronym UID.
@@ -563,7 +564,7 @@ public:
       @param uid is a QString containing an attendee @acronym UID.
       @see attendeeByMail(), attendeeByMails().
     */
-    Attendee::Ptr attendeeByUid(const QString &uid) const;
+    Attendee attendeeByUid(const QString &uid) const;
 
     /**
       Sets the incidences url.
@@ -726,10 +727,16 @@ protected:
     */
     virtual IncidenceBase &assign(const IncidenceBase &other);
 
-    enum VirtualHook {
-        SerializerHook,
-        DeserializerHook
-    };
+    /**
+     * Sub-type specific serialization.
+     */
+    virtual void serialize(QDataStream &out) const;
+    /**
+     * Sub-type specific deserialization.
+     */
+    virtual void deserialize(QDataStream &in);
+
+    enum VirtualHook {};
 
     /**
       Standard trick to add virtuals later.
@@ -749,6 +756,8 @@ private:
     //@cond PRIVATE
     class Private;
     Private *const d;
+
+    Q_DECL_HIDDEN QVariantList attendeesVariant() const;
     //@endcond
 
     friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KCalCore::IncidenceBase::Ptr &);
@@ -758,9 +767,6 @@ private:
 
 /**
  * Incidence serializer.
- * Uses the virtual_hook internally to avoid slicing.
- *
- * // TODO_KDE5: Provide a virtual serialize() method, as done with assign() and equals().
  *
  * @since 4.12
  */
@@ -768,9 +774,6 @@ KCALCORE_EXPORT QDataStream &operator<<(QDataStream &out, const KCalCore::Incide
 
 /**
  * Incidence deserializer.
- * Uses the virtual_hook internally to avoid slicing.
- *
- * // TODO_KDE5: Provide a virtual serialize() method, as done with assign() and equals().
  *
  * @since 4.12
  */
