@@ -117,14 +117,14 @@ public:
     void insertIncidence(const Incidence::Ptr &incidence);
 
     Incidence::Ptr incidence(const QString &uid,
-                             const IncidenceBase::IncidenceType type,
+                             IncidenceBase::IncidenceType type,
                              const QDateTime &recurrenceId = {}) const;
 
     Incidence::Ptr deletedIncidence(const QString &uid,
                                     const QDateTime &recurrenceId,
-                                    const IncidenceBase::IncidenceType type) const;
+                                    IncidenceBase::IncidenceType type) const;
 
-    void deleteAllIncidences(const IncidenceBase::IncidenceType type);
+    void deleteAllIncidences(IncidenceBase::IncidenceType type);
 
 };
 //@endcond
@@ -143,7 +143,7 @@ MemoryCalendar::MemoryCalendar(const QByteArray &timeZoneId)
 
 MemoryCalendar::~MemoryCalendar()
 {
-    close();
+    close(); //NOLINT false clang-analyzer-optin.cplusplus.VirtualCall
     delete d;
 }
 
@@ -181,7 +181,6 @@ bool MemoryCalendar::deleteIncidence(const Incidence::Ptr &incidence)
         d->mIncidences[type].remove(uid, incidence);
         d->mIncidencesByIdentifier.remove(incidence->instanceIdentifier());
         setModified(true);
-        notifyIncidenceDeletedOld(incidence);
         if (deletionTracking()) {
             d->mDeletedIncidences[type].insert(uid, incidence);
         }
@@ -222,7 +221,7 @@ bool MemoryCalendar::deleteIncidenceInstances(const Incidence::Ptr &incidence)
 }
 
 //@cond PRIVATE
-void MemoryCalendar::Private::deleteAllIncidences(const Incidence::IncidenceType incidenceType)
+void MemoryCalendar::Private::deleteAllIncidences(Incidence::IncidenceType incidenceType)
 {
     QHashIterator<QString, Incidence::Ptr>i(mIncidences[incidenceType]);
     while (i.hasNext()) {
@@ -235,7 +234,7 @@ void MemoryCalendar::Private::deleteAllIncidences(const Incidence::IncidenceType
 }
 
 Incidence::Ptr MemoryCalendar::Private::incidence(const QString &uid,
-        const Incidence::IncidenceType type,
+        Incidence::IncidenceType type,
         const QDateTime &recurrenceId) const
 {
     Incidence::List values = ::values(mIncidences[type], uid);
@@ -256,8 +255,8 @@ Incidence::Ptr MemoryCalendar::Private::incidence(const QString &uid,
 
 Incidence::Ptr
 MemoryCalendar::Private::deletedIncidence(const QString &uid,
-    const QDateTime &recurrenceId,
-        const IncidenceBase::IncidenceType type) const
+        const QDateTime &recurrenceId,
+        IncidenceBase::IncidenceType type) const
 {
     if (!q->deletionTracking()) {
         return Incidence::Ptr();
@@ -669,7 +668,6 @@ Event::List MemoryCalendar::rawEvents(const QDate &start,
     const auto ts = timeZone.isValid() ? timeZone : this->timeZone();
     QDateTime st(start, QTime(0, 0, 0), ts);
     QDateTime nd(end, QTime(23, 59, 59, 999), ts);
-    QDateTime yesterStart = st.addDays(-1);
 
     // Get non-recurring events
     QHashIterator<QString, Incidence::Ptr>i(d->mIncidences[Incidence::TypeEvent]);
