@@ -36,7 +36,7 @@
 #include <QString>
 #include <QHash>
 #include <QMetaType>
-#include <QSharedPointer>
+#include <QSharedDataPointer>
 
 namespace KCalCore
 {
@@ -50,16 +50,17 @@ namespace KCalCore
 */
 class KCALCORE_EXPORT Person
 {
-public:
-    /**
-      A shared pointer to a Person object.
-    */
-    typedef QSharedPointer<Person> Ptr;
+    Q_GADGET
+    Q_PROPERTY(bool isEmpty READ isEmpty)
+    Q_PROPERTY(QString fullName READ fullName)
+    Q_PROPERTY(QString name READ name WRITE setName)
+    Q_PROPERTY(QString email READ email WRITE setEmail)
 
+public:
     /**
       List of persons.
     */
-    typedef QVector<Ptr> List;
+    typedef QVector<Person> List;
 
     /**
       Constructs a blank person.
@@ -71,9 +72,9 @@ public:
 
       @param fullName is the name and email of the person in the form
         "FirstName LastName \<mail@domain\>".
-      @return A Person object pointer.
+      @return A Person object.
     */
-    static Person::Ptr fromFullName(const QString &fullName);
+    static Person fromFullName(const QString &fullName);
 
     /**
       Constructs a person with the name @p name and email address @p email.
@@ -97,14 +98,14 @@ public:
     /**
       Returns true if the person name and email address are empty.
     */
-    bool isEmpty() const;
+    Q_REQUIRED_RESULT bool isEmpty() const;
 
     /**
       Returns the full name of this person.
       @return A QString containing the person's full name in the form
         "FirstName LastName \<mail@domain\>".
     */
-    QString fullName() const;
+    Q_REQUIRED_RESULT QString fullName() const;
 
     /**
       Sets the name of the person to @p name.
@@ -120,7 +121,7 @@ public:
 
       @see setName()
     */
-    QString name() const;
+    Q_REQUIRED_RESULT QString name() const;
 
     /**
       Sets the email address for this person to @p email.
@@ -136,7 +137,7 @@ public:
       @return A QString containing the person's email address.
       @see setEmail()
     */
-    QString email() const;
+    Q_REQUIRED_RESULT QString email() const;
 
     /**
       Returns true if person's email address is valid.
@@ -149,26 +150,7 @@ public:
 
       @param email is the email address to validate
     */
-    static bool isValidEmail(const QString &email);
-
-    /**
-      Sets the number of references for this person.
-
-      This can be initialized in a loading function (see ExtendedStorage),
-      where the number of contact appearances etc. are counted.
-
-      @param count number of references
-
-      @see count()
-    */
-    void setCount(int count);
-
-    /**
-      Returns the number of references or zero if it is not initialized.
-
-      @see setCount()
-    */
-    int count() const;
+    Q_REQUIRED_RESULT static bool isValidEmail(const QString &email);
 
     /**
       Compares this with @p person for equality.
@@ -194,27 +176,22 @@ public:
 private:
     //@cond PRIVATE
     class Private;
-    Private *const d;
+    QSharedDataPointer<Private> d;
     //@endcond
 
-    // TODO_KDE5: FIXME: This operator does slicing,if the object is in fact one of the derived classes (Attendee)
-    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &s,
-            const KCalCore::Person::Ptr &person);
-    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &s,
-            KCalCore::Person::Ptr &person);
+    friend KCALCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KCalCore::Person &person);
+    friend KCALCORE_EXPORT QDataStream &operator>>(QDataStream &s, KCalCore::Person &person);
 };
 
 /**
   Serializes the @p person object into the @p stream.
 */
-KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KCalCore::Person::Ptr &person);
+KCALCORE_EXPORT QDataStream &operator<<(QDataStream &stream, const KCalCore::Person &person);
 
 /**
   Initializes the @p person object from the @p stream.
 */
-KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalCore::Person::Ptr &person);
-
-}
+KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalCore::Person &person);
 
 /**
   Return a hash value for a Person argument.
@@ -222,9 +199,11 @@ KCALCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalCore::Person::P
 */
 KCALCORE_EXPORT uint qHash(const KCalCore::Person &key);
 
+}
+
 //@cond PRIVATE
-Q_DECLARE_TYPEINFO(KCalCore::Person::Ptr, Q_MOVABLE_TYPE);
-Q_DECLARE_METATYPE(KCalCore::Person::Ptr)
+Q_DECLARE_TYPEINFO(KCalCore::Person, Q_MOVABLE_TYPE);
+Q_DECLARE_METATYPE(KCalCore::Person)
 //@endcond
 
 #endif
