@@ -22,11 +22,12 @@
   Boston, MA 02110-1301, USA.
 */
 #include "recurrence.h"
-#include "sortablelist.h"
 #include "utils.h"
+#include "recurrencehelper_p.h"
 
 #include "kcalcore_debug.h"
 
+#include <QDataStream>
 #include <QTimeZone>
 #include <QBitArray>
 #include <QTime>
@@ -60,9 +61,9 @@ public:
 
     RecurrenceRule::List mExRules;
     RecurrenceRule::List mRRules;
-    SortableList<QDateTime> mRDateTimes;
+    QList<QDateTime> mRDateTimes;
     DateList mRDates;
-    SortableList<QDateTime> mExDateTimes;
+    QList<QDateTime> mExDateTimes;
     DateList mExDates;
     QDateTime mStartDateTime;    // date/time of first recurrence
     QList<RecurrenceObserver *> mObservers;
@@ -335,12 +336,11 @@ bool Recurrence::recursOn(const QDate &qd, const QTimeZone &timeZone) const
     }
 
     // First handle dates. Exrules override
-    if (d->mExDates.containsSorted(qd)) {
+    if (std::binary_search(d->mExDates.constBegin(), d->mExDates.constEnd(), qd)) {
         return false;
     }
 
     int i, end;
-    TimeList tms;
     // For all-day events a matching exrule excludes the whole day
     // since exclusions take precedence over inclusions, we know it can't occur on that day.
     if (allDay()) {
@@ -351,7 +351,7 @@ bool Recurrence::recursOn(const QDate &qd, const QTimeZone &timeZone) const
         }
     }
 
-    if (d->mRDates.containsSorted(qd)) {
+    if (std::binary_search(d->mRDates.constBegin(), d->mRDates.constEnd(), qd)) {
         return true;
     }
 
@@ -398,8 +398,8 @@ bool Recurrence::recursAt(const QDateTime &dt) const
     const auto dtrecur = dt.toTimeZone(d->mStartDateTime.timeZone());
 
     // if it's excluded anyway, don't bother to check if it recurs at all.
-    if (d->mExDateTimes.containsSorted(dtrecur) ||
-            d->mExDates.containsSorted(dtrecur.date())) {
+    if (std::binary_search(d->mExDateTimes.constBegin(), d->mExDateTimes.constEnd(), dtrecur) ||
+        std::binary_search(d->mExDates.constBegin(), d->mExDates.constEnd(), dtrecur.date())) {
         return false;
     }
     int i, end;
@@ -410,7 +410,8 @@ bool Recurrence::recursAt(const QDateTime &dt) const
     }
 
     // Check explicit recurrences, then rrules.
-    if (startDateTime() == dtrecur || d->mRDateTimes.containsSorted(dtrecur)) {
+    if (startDateTime() == dtrecur ||
+        std::binary_search(d->mRDateTimes.constBegin(), d->mRDateTimes.constEnd(), dtrecur)) {
         return true;
     }
     for (i = 0, end = d->mRRules.count();  i < end;  ++i) {
@@ -427,7 +428,7 @@ bool Recurrence::recursAt(const QDateTime &dt) const
     rdates, an invalid date is returned. */
 QDateTime Recurrence::endDateTime() const
 {
-    SortableList<QDateTime> dts;
+    QList<QDateTime> dts;
     dts << startDateTime();
     if (!d->mRDates.isEmpty()) {
         dts << QDateTime(d->mRDates.last(), QTime(0, 0, 0), d->mStartDateTime.timeZone());
@@ -443,7 +444,7 @@ QDateTime Recurrence::endDateTime() const
         }
         dts << rl;
     }
-    dts.sortUnique();
+    sortAndRemoveDuplicates(dts);
     return dts.isEmpty() ? QDateTime() : dts.last();
 }
 
@@ -648,7 +649,7 @@ QBitArray Recurrence::days() const
     days.fill(0);
     RecurrenceRule *rrule = defaultRRuleConst();
     if (rrule) {
-        QList<RecurrenceRule::WDayPos> bydays = rrule->byDays();
+        const QList<RecurrenceRule::WDayPos> &bydays = rrule->byDays();
         for (int i = 0; i < bydays.size(); ++i) {
             if (bydays.at(i).pos() == 0) {
                 days.setBit(bydays.at(i).day() - 1);
@@ -873,11 +874,11 @@ void Recurrence::setMonthlyDate(const QList< int > &monthlyDays)
         return;
     }
 
-    SortableList<int> mD(monthlyDays);
-    SortableList<int> rbD(rrule->byMonthDays());
+    QList<int> mD(monthlyDays);
+    QList<int> rbD(rrule->byMonthDays());
 
-    mD.sortUnique();
-    rbD.sortUnique();
+    sortAndRemoveDuplicates(mD);
+    sortAndRemoveDuplicates(rbD);
 
     if (mD != rbD) {
         rrule->setByMonthDays(monthlyDays);
@@ -914,11 +915,11 @@ void Recurrence::setYearlyDay(const QList<int> &days)
         return;
     }
 
-    SortableList<int> d(days);
-    SortableList<int> bYD(rrule->byYearDays());
+    QList<int> d(days);
+    QList<int> bYD(rrule->byYearDays());
 
-    d.sortUnique();
-    bYD.sortUnique();
+    sortAndRemoveDuplicates(d);
+    sortAndRemoveDuplicates(bYD);
 
     if (d != bYD) {
         rrule->setByYearDays(days);
@@ -978,11 +979,11 @@ void Recurrence::setYearlyMonth(const QList<int> &months)
         return;
     }
 
-    SortableList<int> m(months);
-    SortableList<int> bM(rrule->byMonths());
+    QList<int> m(months);
+    QList<int> bM(rrule->byMonths());
 
-    m.sortUnique();
-    bM.sortUnique();
+    sortAndRemoveDuplicates(m);
+    sortAndRemoveDuplicates(bM);
 
     if (m != bM) {
         rrule->setByMonths(months);
@@ -997,7 +998,7 @@ TimeList Recurrence::recurTimesOn(const QDate &date, const QTimeZone &timeZone)
     TimeList times;
 
     // The whole day is excepted
-    if (d->mExDates.containsSorted(date)) {
+    if (std::binary_search(d->mExDates.constBegin(), d->mExDates.constEnd(), date)) {
         return times;
     }
 
@@ -1029,7 +1030,7 @@ TimeList Recurrence::recurTimesOn(const QDate &date, const QTimeZone &timeZone)
     for (i = 0, end = d->mRRules.count();  i < end;  ++i) {
         times += d->mRRules[i]->recurTimesOn(date, timeZone);
     }
-    times.sortUnique();
+    sortAndRemoveDuplicates(times);
 
     foundDate = false;
     TimeList extimes;
@@ -1047,22 +1048,15 @@ TimeList Recurrence::recurTimesOn(const QDate &date, const QTimeZone &timeZone)
             extimes += d->mExRules[i]->recurTimesOn(date, timeZone);
         }
     }
-    extimes.sortUnique();
-
-    int st = 0;
-    for (i = 0, end = extimes.count();  i < end;  ++i) {
-        int j = times.removeSorted(extimes[i], st);
-        if (j >= 0) {
-            st = j;
-        }
-    }
+    sortAndRemoveDuplicates(extimes);
+    inplaceSetDifference(times, extimes);
     return times;
 }
 
-SortableList<QDateTime> Recurrence::timesInInterval(const QDateTime &start, const QDateTime &end) const
+QList<QDateTime> Recurrence::timesInInterval(const QDateTime &start, const QDateTime &end) const
 {
     int i, count;
-    SortableList<QDateTime> times;
+    QList<QDateTime> times;
     for (i = 0, count = d->mRRules.count();  i < count;  ++i) {
         times += d->mRRules[i]->timesInInterval(start, end);
     }
@@ -1095,7 +1089,7 @@ SortableList<QDateTime> Recurrence::timesInInterval(const QDateTime &start, cons
         times += d->mStartDateTime;
     }
 
-    times.sortUnique();
+    sortAndRemoveDuplicates(times);
 
     // Remove excluded times
     int idt = 0;
@@ -1109,21 +1103,13 @@ SortableList<QDateTime> Recurrence::timesInInterval(const QDateTime &start, cons
             --enddt;
         }
     }
-    SortableList<QDateTime> extimes;
+    QList<QDateTime> extimes;
     for (i = 0, count = d->mExRules.count();  i < count;  ++i) {
         extimes += d->mExRules[i]->timesInInterval(start, end);
     }
     extimes += d->mExDateTimes;
-    extimes.sortUnique();
-
-    int st = 0;
-    for (i = 0, count = extimes.count();  i < count;  ++i) {
-        int j = times.removeSorted(extimes[i], st);
-        if (j >= 0) {
-            st = j;
-        }
-    }
-
+    sortAndRemoveDuplicates(extimes);
+    inplaceSetDifference(times, extimes);
     return times;
 }
 
@@ -1149,21 +1135,20 @@ QDateTime Recurrence::getNextDateTime(const QDateTime &preDateTime) const
         //      of preDateTime). Loop at most 1000 times.
         ++loop;
         // First, get the next recurrence from the RDate lists
-        SortableList<QDateTime> dates;
+        QList<QDateTime> dates;
         if (nextDT < startDateTime()) {
             dates << startDateTime();
         }
 
-        int end;
         // Assume that the rdatetime list is sorted
-        int i = d->mRDateTimes.findGT(nextDT);
-        if (i >= 0) {
-            dates << d->mRDateTimes[i];
+        const auto it = std::upper_bound(d->mRDateTimes.constBegin(), d->mRDateTimes.constEnd(), nextDT);
+        if (it != d->mRDateTimes.constEnd()) {
+            dates << *it;
         }
 
         QDateTime kdt(startDateTime());
-        for (i = 0, end = d->mRDates.count();  i < end;  ++i) {
-            kdt.setDate(d->mRDates[i]);
+        for (const auto &date : qAsConst(d->mRDates)) {
+            kdt.setDate(date);
             if (kdt > nextDT) {
                 dates << kdt;
                 break;
@@ -1171,26 +1156,26 @@ QDateTime Recurrence::getNextDateTime(const QDateTime &preDateTime) const
         }
 
         // Add the next occurrences from all RRULEs.
-        for (i = 0, end = d->mRRules.count();  i < end;  ++i) {
-            QDateTime dt = d->mRRules[i]->getNextDate(nextDT);
+        for (const auto &rule : qAsConst(d->mRRules)) {
+            QDateTime dt = rule->getNextDate(nextDT);
             if (dt.isValid()) {
                 dates << dt;
             }
         }
 
         // Take the first of these (all others can't be used later on)
-        dates.sortUnique();
+        sortAndRemoveDuplicates(dates);
         if (dates.isEmpty()) {
             return QDateTime();
         }
         nextDT = dates.first();
 
         // Check if that date/time is excluded explicitly or by an exrule:
-        if (!d->mExDates.containsSorted(nextDT.date()) &&
-                !d->mExDateTimes.containsSorted(nextDT)) {
+        if (!std::binary_search(d->mExDates.constBegin(), d->mExDates.constEnd(), nextDT.date()) &&
+            !std::binary_search(d->mExDateTimes.constBegin(), d->mExDateTimes.constEnd(), nextDT)) {
             bool allowed = true;
-            for (i = 0, end = d->mExRules.count();  i < end;  ++i) {
-                allowed = allowed && !(d->mExRules[i]->recursAt(nextDT));
+            for (const auto &rule : qAsConst(d->mExRules)) {
+                allowed = allowed && !rule->recursAt(nextDT);
             }
             if (allowed) {
                 return nextDT;
@@ -1221,19 +1206,19 @@ QDateTime Recurrence::getPreviousDateTime(const QDateTime &afterDateTime) const
         //      of preDateTime). Loop at most 1000 times.
         ++loop;
         // First, get the next recurrence from the RDate lists
-        SortableList<QDateTime> dates;
+        QList<QDateTime> dates;
         if (prevDT > startDateTime()) {
             dates << startDateTime();
         }
 
-        int i = d->mRDateTimes.findLT(prevDT);
-        if (i >= 0) {
-            dates << d->mRDateTimes[i];
+        const auto it = strictLowerBound(d->mRDateTimes.constBegin(), d->mRDateTimes.constEnd(), prevDT);
+        if (it != d->mRDateTimes.constEnd()) {
+            dates << *it;
         }
 
         QDateTime kdt(startDateTime());
-        for (i = d->mRDates.count();  --i >= 0;) {
-            kdt.setDate(d->mRDates[i]);
+        for (const auto &date : qAsConst(d->mRDates)) {
+            kdt.setDate(date);
             if (kdt < prevDT) {
                 dates << kdt;
                 break;
@@ -1241,27 +1226,26 @@ QDateTime Recurrence::getPreviousDateTime(const QDateTime &afterDateTime) const
         }
 
         // Add the previous occurrences from all RRULEs.
-        int end;
-        for (i = 0, end = d->mRRules.count();  i < end;  ++i) {
-            QDateTime dt = d->mRRules[i]->getPreviousDate(prevDT);
+        for (const auto &rule : qAsConst(d->mRRules)) {
+            QDateTime dt = rule->getPreviousDate(prevDT);
             if (dt.isValid()) {
                 dates << dt;
             }
         }
 
         // Take the last of these (all others can't be used later on)
-        dates.sortUnique();
+        sortAndRemoveDuplicates(dates);
         if (dates.isEmpty()) {
             return QDateTime();
         }
         prevDT = dates.last();
 
         // Check if that date/time is excluded explicitly or by an exrule:
-        if (!d->mExDates.containsSorted(prevDT.date()) &&
-                !d->mExDateTimes.containsSorted(prevDT)) {
+        if (!std::binary_search(d->mExDates.constBegin(), d->mExDates.constEnd(), prevDT.date()) &&
+            !std::binary_search(d->mExDateTimes.constBegin(), d->mExDateTimes.constEnd(), prevDT)) {
             bool allowed = true;
-            for (i = 0, end = d->mExRules.count();  i < end;  ++i) {
-                allowed = allowed && !(d->mExRules[i]->recursAt(prevDT));
+            for (const auto &rule : qAsConst(d->mExRules)) {
+                allowed = allowed && !rule->recursAt(prevDT);
             }
             if (allowed) {
                 return prevDT;
@@ -1353,19 +1337,19 @@ void Recurrence::deleteExRule(RecurrenceRule *exrule)
     updated();
 }
 
-SortableList<QDateTime> Recurrence::rDateTimes() const
+QList<QDateTime> Recurrence::rDateTimes() const
 {
     return d->mRDateTimes;
 }
 
-void Recurrence::setRDateTimes(const SortableList<QDateTime> &rdates)
+void Recurrence::setRDateTimes(const QList<QDateTime> &rdates)
 {
     if (d->mRecurReadOnly) {
         return;
     }
 
     d->mRDateTimes = rdates;
-    d->mRDateTimes.sortUnique();
+    sortAndRemoveDuplicates(d->mRDateTimes);
     updated();
 }
 
@@ -1375,7 +1359,7 @@ void Recurrence::addRDateTime(const QDateTime &rdate)
         return;
     }
 
-    d->mRDateTimes.insertSorted(rdate);
+    setInsert(d->mRDateTimes, rdate);
     updated();
 }
 
@@ -1391,7 +1375,7 @@ void Recurrence::setRDates(const DateList &rdates)
     }
 
     d->mRDates = rdates;
-    d->mRDates.sortUnique();
+    sortAndRemoveDuplicates(d->mRDates);
     updated();
 }
 
@@ -1401,23 +1385,23 @@ void Recurrence::addRDate(const QDate &rdate)
         return;
     }
 
-    d->mRDates.insertSorted(rdate);
+    setInsert(d->mRDates, rdate);
     updated();
 }
 
-SortableList<QDateTime> Recurrence::exDateTimes() const
+QList<QDateTime> Recurrence::exDateTimes() const
 {
     return d->mExDateTimes;
 }
 
-void Recurrence::setExDateTimes(const SortableList<QDateTime> &exdates)
+void Recurrence::setExDateTimes(const QList<QDateTime> &exdates)
 {
     if (d->mRecurReadOnly) {
         return;
     }
 
     d->mExDateTimes = exdates;
-    d->mExDateTimes.sortUnique();
+    sortAndRemoveDuplicates(d->mExDateTimes);
 }
 
 void Recurrence::addExDateTime(const QDateTime &exdate)
@@ -1426,7 +1410,7 @@ void Recurrence::addExDateTime(const QDateTime &exdate)
         return;
     }
 
-    d->mExDateTimes.insertSorted(exdate);
+    setInsert(d->mExDateTimes, exdate);
     updated();
 }
 
@@ -1442,7 +1426,7 @@ void Recurrence::setExDates(const DateList &exdates)
     }
 
     DateList l = exdates;
-    l.sortUnique();
+    sortAndRemoveDuplicates(l);
 
     if (d->mExDates != l) {
         d->mExDates = l;
@@ -1456,7 +1440,7 @@ void Recurrence::addExDate(const QDate &exdate)
         return;
     }
 
-    d->mExDates.insertSorted(exdate);
+    setInsert(d->mExDates, exdate);
     updated();
 }
 
@@ -1515,8 +1499,8 @@ KCALCORE_EXPORT QDataStream &KCalCore::operator<<(QDataStream &out, KCalCore::Re
         return out;
     }
 
-    serializeQDateTimeSortableList(out, r->d->mRDateTimes);
-    serializeQDateTimeSortableList(out, r->d->mExDateTimes);
+    serializeQDateTimeList(out, r->d->mRDateTimes);
+    serializeQDateTimeList(out, r->d->mExDateTimes);
     out << r->d->mRDates;
     serializeQDateTimeAsKDateTime(out, r->d->mStartDateTime);
     out << r->d->mCachedType
@@ -1542,8 +1526,8 @@ KCALCORE_EXPORT QDataStream &KCalCore::operator>>(QDataStream &in, KCalCore::Rec
 
     int rruleCount, exruleCount;
 
-    deserializeQDateTimeSortableList(in, r->d->mRDateTimes);
-    deserializeQDateTimeSortableList(in, r->d->mExDateTimes);
+    deserializeQDateTimeList(in, r->d->mRDateTimes);
+    deserializeQDateTimeList(in, r->d->mExDateTimes);
     in >> r->d->mRDates;
     deserializeKDateTimeAsQDateTime(in, r->d->mStartDateTime);
     in >> r->d->mCachedType
