@@ -22,7 +22,9 @@
 #include "recurrencerule.h"
 #include "utils.h"
 #include "kcalcore_debug.h"
+#include "recurrencehelper_p.h"
 
+#include <QDataStream>
 #include <QStringList>
 #include <QTime>
 #include <QTimeZone>
@@ -666,14 +668,19 @@ bool Constraint::readDateTime(const QDateTime &dt, RecurrenceRule::PeriodType ty
     // Really fall through! Only weekly needs to be treated differently!
     case RecurrenceRule::rSecondly:
         second = dt.time().second();
+        Q_FALLTHROUGH();
     case RecurrenceRule::rMinutely:
         minute = dt.time().minute();
+        Q_FALLTHROUGH();
     case RecurrenceRule::rHourly:
         hour = dt.time().hour();
+        Q_FALLTHROUGH();
     case RecurrenceRule::rDaily:
         day = dt.date().day();
+        Q_FALLTHROUGH();
     case RecurrenceRule::rMonthly:
         month = dt.date().month();
+        Q_FALLTHROUGH();
     case RecurrenceRule::rYearly:
         year = dt.date().year();
         break;
@@ -719,7 +726,7 @@ public:
     bool buildCache() const;
     Constraint getNextValidDateInterval(const QDateTime &preDate, PeriodType type) const;
     Constraint getPreviousValidDateInterval(const QDateTime &afterDate, PeriodType type) const;
-    SortableList<QDateTime> datesForInterval(const Constraint &interval, PeriodType type) const;
+    QList<QDateTime> datesForInterval(const Constraint &interval, PeriodType type) const;
 
     RecurrenceRule *mParent;
     QString mRRule;            // RRULE string
@@ -750,7 +757,7 @@ public:
     QList<RuleObserver *> mObservers;
 
     // Cache for duration
-    mutable SortableList<QDateTime> mCachedDates;
+    mutable QList<QDateTime> mCachedDates;
     mutable QDateTime mCachedDateEnd;
     mutable QDateTime mCachedLastDate;   // when mCachedDateEnd invalid, last date checked
     mutable bool mCached;
@@ -1268,24 +1275,29 @@ void RecurrenceRule::Private::buildConstraints()
                 mByYearDays.isEmpty() && mByMonths.isEmpty()) {
             fixConstraint(setMonth, mDateStart.date().month());
         }
+        Q_FALLTHROUGH();
     case rMonthly:
         if (mByDays.isEmpty() && mByWeekNumbers.isEmpty() &&
                 mByYearDays.isEmpty() && mByMonthDays.isEmpty()) {
             fixConstraint(setDay, mDateStart.date().day());
         }
+        Q_FALLTHROUGH();
     case rWeekly:
     case rDaily:
         if (mByHours.isEmpty()) {
             fixConstraint(setHour, mDateStart.time().hour());
         }
+        Q_FALLTHROUGH();
     case rHourly:
         if (mByMinutes.isEmpty()) {
             fixConstraint(setMinute, mDateStart.time().minute());
         }
+        Q_FALLTHROUGH();
     case rMinutely:
         if (mBySeconds.isEmpty()) {
             fixConstraint(setSecond, mDateStart.time().second());
         }
+        Q_FALLTHROUGH();
     case rSecondly:
     default:
         break;
@@ -1330,9 +1342,9 @@ bool RecurrenceRule::Private::buildCache() const
     auto dts = datesForInterval(interval, mPeriod);
     // Only use dates after the event has started (start date is only included
     // if it matches)
-    int i = dts.findLT(mDateStart);
-    if (i >= 0) {
-        dts.erase(dts.begin(), dts.begin() + i + 1);
+    const auto it = strictLowerBound(dts.begin(), dts.end(), mDateStart);
+    if (it != dts.end()) {
+        dts.erase(dts.begin(), it + 1);
     }
 
     // some validity checks to avoid infinite loops (i.e. if we have
@@ -1485,7 +1497,6 @@ bool RecurrenceRule::recursOn(const QDate &qd, const QTimeZone &timeZone) const
     Constraint interval(d->getNextValidDateInterval(start, recurrenceType()));
     // Constraint::matches is quite efficient, so first check if it can occur at
     // all before we calculate all actual dates.
-    match = false;
     Constraint intervalm = interval;
     do {
         match = intervalm.matches(startDay, recurrenceType());
@@ -1507,9 +1518,9 @@ bool RecurrenceRule::recursOn(const QDate &qd, const QTimeZone &timeZone) const
     // but BYSETPOS selects only one of these matching dates!
     do {
         auto dts = d->datesForInterval(interval, recurrenceType());
-        int i = dts.findGE(start);
-        if (i >= 0) {
-            return dts[i] <= end;
+        const auto it = std::lower_bound(dts.constBegin(), dts.constEnd(), start);
+        if (it != dts.constEnd()) {
+            return *it <= end;
         }
         interval.increase(recurrenceType(), frequency());
     } while (interval.intervalDateTime(recurrenceType()).isValid() &&
@@ -1626,9 +1637,9 @@ QDateTime RecurrenceRule::getPreviousDate(const QDateTime &afterDate) const
         if (!d->mCached) {
             d->buildCache();
         }
-        int i = d->mCachedDates.findLT(toDate);
-        if (i >= 0) {
-            return d->mCachedDates[i];
+        const auto it = strictLowerBound(d->mCachedDates.constBegin(), d->mCachedDates.constEnd(), toDate);
+        if (it != d->mCachedDates.constEnd()) {
+            return *it;
         }
         return QDateTime();
     }
@@ -1639,10 +1650,10 @@ QDateTime RecurrenceRule::getPreviousDate(const QDateTime &afterDate) const
     }
 
     Constraint interval(d->getPreviousValidDateInterval(prev, recurrenceType()));
-    auto dts = d->datesForInterval(interval, recurrenceType());
-    int i = dts.findLT(prev);
-    if (i >= 0) {
-        return (dts[i] >= d->mDateStart) ? dts[i] : QDateTime();
+    const auto dts = d->datesForInterval(interval, recurrenceType());
+    const auto it = strictLowerBound(dts.begin(), dts.end(), prev);
+    if (it != dts.end()) {
+        return ((*it) >= d->mDateStart) ? (*it) : QDateTime();
     }
 
     // Previous interval. As soon as we find an occurrence, we're done.
@@ -1688,18 +1699,18 @@ QDateTime RecurrenceRule::getNextDate(const QDateTime &preDate) const
         if (!d->mCached) {
             d->buildCache();
         }
-        int i = d->mCachedDates.findGT(fromDate);
-        if (i >= 0) {
-            return d->mCachedDates[i];
+        const auto it = std::upper_bound(d->mCachedDates.constBegin(), d->mCachedDates.constEnd(), fromDate);
+        if (it != d->mCachedDates.constEnd()) {
+            return *it;
         }
     }
 
     QDateTime end = endDt();
     Constraint interval(d->getNextValidDateInterval(fromDate, recurrenceType()));
-    auto dts = d->datesForInterval(interval, recurrenceType());
-    int i = dts.findGT(fromDate);
-    if (i >= 0) {
-        return (d->mDuration < 0 || dts[i] <= end) ? dts[i] : QDateTime();
+    const auto dts = d->datesForInterval(interval, recurrenceType());
+    const auto it = std::upper_bound(dts.begin(), dts.end(), fromDate);
+    if (it != dts.end()) {
+        return (d->mDuration < 0 || *it <= end) ? *it : QDateTime();
     }
     interval.increase(recurrenceType(), frequency());
     if (d->mDuration >= 0 && interval.intervalDateTime(recurrenceType()) > end) {
@@ -1726,12 +1737,12 @@ QDateTime RecurrenceRule::getNextDate(const QDateTime &preDate) const
     return QDateTime();
 }
 
-SortableList<QDateTime> RecurrenceRule::timesInInterval(const QDateTime &dtStart,
+QList<QDateTime> RecurrenceRule::timesInInterval(const QDateTime &dtStart,
                                                         const QDateTime &dtEnd) const
 {
     const QDateTime start = dtStart.toTimeZone(d->mDateStart.timeZone());
     const QDateTime end = dtEnd.toTimeZone(d->mDateStart.timeZone());
-    SortableList<QDateTime> result;
+    QList<QDateTime> result;
     if (end < d->mDateStart) {
         return result;    // before start of recurrence
     }
@@ -1783,17 +1794,13 @@ SortableList<QDateTime> RecurrenceRule::timesInInterval(const QDateTime &dtStart
         if (d->mCachedDateEnd.isValid() && start > d->mCachedDateEnd) {
             return result;    // beyond end of recurrence
         }
-        int i = d->mCachedDates.findGE(start);
-        if (i >= 0) {
-            int iend = d->mCachedDates.findGT(enddt, i);
-            if (iend < 0) {
-                iend = d->mCachedDates.count();
-            } else {
+        const auto it = std::lower_bound(d->mCachedDates.constBegin(), d->mCachedDates.constEnd(), start);
+        if (it != d->mCachedDates.constEnd()) {
+            const auto itEnd = std::upper_bound(it, d->mCachedDates.constEnd(), enddt);
+            if (itEnd != d->mCachedDates.constEnd()) {
                 done = true;
             }
-            while (i < iend) {
-                result += d->mCachedDates[i++];
-            }
+            std::copy(it, itEnd, std::back_inserter(result));
         }
         if (d->mCachedDateEnd.isValid()) {
             done = true;
@@ -1812,22 +1819,16 @@ SortableList<QDateTime> RecurrenceRule::timesInInterval(const QDateTime &dtStart
     int loop = 0;
     do {
         auto dts = d->datesForInterval(interval, recurrenceType());
-        int i = 0;
-        int iend = dts.count();
+        auto it = dts.begin();
+        auto itEnd = dts.end();
         if (loop == 0) {
-            i = dts.findGE(st);
-            if (i < 0) {
-                i = iend;
-            }
+            it = std::lower_bound(dts.begin(), dts.end(), st);
         }
-        int j = dts.findGT(enddt, i);
-        if (j >= 0) {
-            iend = j;
+        itEnd = std::upper_bound(it, dts.end(), enddt);
+        if (itEnd != dts.end()) {
             loop = LOOP_LIMIT;
         }
-        while (i < iend) {
-            result += dts[i++];
-        }
+        std::copy(it, itEnd, std::back_inserter(result));
         // Increase the interval.
         interval.increase(recurrenceType(), frequency());
     } while (++loop < LOOP_LIMIT &&
@@ -1857,8 +1858,10 @@ Constraint RecurrenceRule::Private::getPreviousValidDateInterval(const QDateTime
     // by the factor 60 and 60*60! Same for weekly and daily (factor 7)
     case rHourly:
         modifier *= 60;
+        Q_FALLTHROUGH();
     case rMinutely:
         modifier *= 60;
+        Q_FALLTHROUGH();
     case rSecondly:
         periods = static_cast<int>(start.secsTo(toDate) / modifier);
         // round it down to the next lower multiple of frequency:
@@ -1871,6 +1874,7 @@ Constraint RecurrenceRule::Private::getPreviousValidDateInterval(const QDateTime
         toDate = toDate.addDays(-(7 + toDate.date().dayOfWeek() - mWeekStart) % 7);
         start = start.addDays(-(7 + start.date().dayOfWeek() - mWeekStart) % 7);
         modifier *= 7;
+        Q_FALLTHROUGH();
     case rDaily:
         periods = start.daysTo(toDate) / modifier;
         // round it down to the next lower multiple of frequency:
@@ -1929,8 +1933,10 @@ Constraint RecurrenceRule::Private::getNextValidDateInterval(const QDateTime &dt
     // by the factor 60 and 60*60! Same for weekly and daily (factor 7)
     case rHourly:
         modifier *= 60;
+        Q_FALLTHROUGH();
     case rMinutely:
         modifier *= 60;
+        Q_FALLTHROUGH();
     case rSecondly:
         periods = static_cast<int>(start.secsTo(toDate) / modifier);
         periods = qMax(0L, periods);
@@ -1944,6 +1950,7 @@ Constraint RecurrenceRule::Private::getNextValidDateInterval(const QDateTime &dt
         toDate = toDate.addDays(-(7 + toDate.date().dayOfWeek() - mWeekStart) % 7);
         start = start.addDays(-(7 + start.date().dayOfWeek() - mWeekStart) % 7);
         modifier *= 7;
+        Q_FALLTHROUGH();
     case rDaily:
         periods = start.daysTo(toDate) / modifier;
         periods = qMax(0L, periods);
@@ -1980,7 +1987,7 @@ Constraint RecurrenceRule::Private::getNextValidDateInterval(const QDateTime &dt
     return Constraint(nextValid, type, mWeekStart);
 }
 
-SortableList<QDateTime> RecurrenceRule::Private::datesForInterval(const Constraint &interval,
+QList<QDateTime> RecurrenceRule::Private::datesForInterval(const Constraint &interval,
                                                                   PeriodType type) const
 {
     /* -) Loop through constraints,
@@ -1989,7 +1996,7 @@ SortableList<QDateTime> RecurrenceRule::Private::datesForInterval(const Constrai
        -) if complete => add that one date to the date list
        -) Loop through all missing fields => For each add the resulting
     */
-    SortableList<QDateTime> lst;
+    QList<QDateTime> lst;
     for (int i = 0, iend = mConstraints.count(); i < iend; ++i) {
         Constraint merged(interval);
         if (merged.merge(mConstraints[i])) {
@@ -2003,7 +2010,7 @@ SortableList<QDateTime> RecurrenceRule::Private::datesForInterval(const Constrai
         }
     }
     // Sort it so we can apply the BySetPos. Also some logic relies on this being sorted
-    lst.sortUnique();
+    sortAndRemoveDuplicates(lst);
 
     /*if ( lst.isEmpty() ) {
       qCDebug(KCALCORE_LOG) << "         No Dates in Interval";
@@ -2029,7 +2036,7 @@ SortableList<QDateTime> RecurrenceRule::Private::datesForInterval(const Constrai
                 lst.append(tmplst[pos]);
             }
         }
-        lst.sortUnique();
+        sortAndRemoveDuplicates(lst);
     }
 
     return lst;
@@ -2063,8 +2070,7 @@ void RecurrenceRule::dump() const
     if (!d->mByDays.isEmpty()) {
         QStringList lst;
         for (int i = 0, iend = d->mByDays.count();  i < iend;  ++i) {
-            \
-            lst.append((d->mByDays[i].pos() ? QString::number(d->mByDays[i].pos()) : QStringLiteral("")) +
+            lst.append((d->mByDays[i].pos() ? QString::number(d->mByDays[i].pos()) : QLatin1String("")) +
                        DateHelper::dayName(d->mByDays[i].day()));
         }
         qCDebug(KCALCORE_LOG) << "   ByDays:    " << lst.join(QStringLiteral(", "));
