@@ -33,7 +33,6 @@
 
 #include "kcalcore_export.h"
 #include "incidence.h"
-#include "supertrait.h"
 
 namespace KCalCore
 {
@@ -55,6 +54,11 @@ public:
     */
     typedef QVector<Ptr> List;
 
+    ///@cond PRIVATE
+    // needed for Akonadi polymorphic payload support
+    typedef Incidence SuperClass;
+    ///@endcond
+
     /**
       Constructs an empty to-do.
     */
@@ -343,8 +347,8 @@ private:
     Todo &operator=(const Todo &other);
 
     // For polymorfic serialization
-    void serialize(QDataStream &out);
-    void deserialize(QDataStream &in);
+    void serialize(QDataStream &out) const override;
+    void deserialize(QDataStream &in) override;
 
     //@cond PRIVATE
     class Private;
@@ -358,12 +362,6 @@ private:
 Q_DECLARE_TYPEINFO(KCalCore::Todo::Ptr, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(KCalCore::Todo::Ptr)
 Q_DECLARE_METATYPE(KCalCore::Todo *)
-
-namespace Akonadi
-{
-// super class trait specialization
-template <> struct SuperClass<KCalCore::Todo> : public SuperClassTrait<KCalCore::Incidence> {};
-}
 //@endcond
 
 #endif
