@@ -217,7 +217,7 @@ Todo::Ptr VCalFormat::VTodoToEvent(VObject *vtodo)
         anEvent->setOrganizer(QString::fromUtf8(s = fakeCString(vObjectUStringZValue(vo))));
         deleteStr(s);
     } else {
-        if (d->mCalendar->owner()->name() != QLatin1String("Unknown Name")) {
+        if (d->mCalendar->owner().name() != QLatin1String("Unknown Name")) {
             anEvent->setOrganizer(d->mCalendar->owner());
         }
     }
@@ -227,7 +227,7 @@ Todo::Ptr VCalFormat::VTodoToEvent(VObject *vtodo)
     while (moreIteration(&voi)) {
         vo = nextVObject(&voi);
         if (strcmp(vObjectName(vo), VCAttendeeProp) == 0) {
-            Attendee::Ptr a;
+            Attendee a;
             VObject *vp;
             s = fakeCString(vObjectUStringZValue(vo));
             QString tmpStr = QString::fromUtf8(s);
@@ -237,26 +237,24 @@ Todo::Ptr VCalFormat::VTodoToEvent(VObject *vtodo)
             if ((emailPos1 = tmpStr.indexOf(QLatin1Char('<'))) > 0) {
                 // both email address and name
                 int emailPos2 = tmpStr.lastIndexOf(QLatin1Char('>'));
-                a = Attendee::Ptr(new Attendee(tmpStr.left(emailPos1 - 1),
-                                               tmpStr.mid(emailPos1 + 1,
-                                                       emailPos2 - (emailPos1 + 1))));
+                a = Attendee(tmpStr.left(emailPos1 - 1), tmpStr.mid(emailPos1 + 1, emailPos2 - (emailPos1 + 1)));
             } else if (tmpStr.indexOf(QLatin1Char('@')) > 0) {
                 // just an email address
-                a = Attendee::Ptr(new Attendee(QString(), tmpStr));
+                a = Attendee(QString(), tmpStr);
             } else {
                 // just a name
                 // WTF??? Replacing the spaces of a name and using this as email?
                 QString email = tmpStr.replace(QLatin1Char(' '), QLatin1Char('.'));
-                a = Attendee::Ptr(new Attendee(tmpStr, email));
+                a = Attendee(tmpStr, email);
             }
 
             // is there an RSVP property?
             if ((vp = isAPropertyOf(vo, VCRSVPProp)) != nullptr) {
-                a->setRSVP(vObjectStringZValue(vp));
+                a.setRSVP(vObjectStringZValue(vp));
             }
             // is there a status property?
             if ((vp = isAPropertyOf(vo, VCStatusProp)) != nullptr) {
-                a->setStatus(readStatus(vObjectStringZValue(vp)));
+                a.setStatus(readStatus(vObjectStringZValue(vp)));
             }
             // add the attendee
             anEvent->addAttendee(a);
@@ -341,42 +339,46 @@ Todo::Ptr VCalFormat::VTodoToEvent(VObject *vtodo)
         anEvent->setDtStart(QDateTime());
     }
 
-    // repeat stuff
+    // recurrence stuff
     if ((vo = isAPropertyOf(vtodo, VCRRuleProp)) != nullptr) {
+        uint recurrenceType = Recurrence::rNone;
+        int recurrenceTypeAbbrLen = 0;
+
         QString tmpStr = (QString::fromUtf8(s = fakeCString(vObjectUStringZValue(vo))));
         deleteStr(s);
         tmpStr = tmpStr.simplified();
-        tmpStr = tmpStr.toUpper();
-        // first, read the type of the recurrence
-        int typelen = 1;
-        uint type = Recurrence::rNone;
-        if (tmpStr.left(1) == QStringLiteral("D")) {
-            type = Recurrence::rDaily;
-        } else if (tmpStr.left(1) == QStringLiteral("W")) {
-            type = Recurrence::rWeekly;
-        } else {
-            typelen = 2;
-            if (tmpStr.left(2) == QStringLiteral("MP")) {
-                type = Recurrence::rMonthlyPos;
-            } else if (tmpStr.left(2) == QStringLiteral("MD")) {
-                type = Recurrence::rMonthlyDay;
-            } else if (tmpStr.left(2) == QStringLiteral("YM")) {
-                type = Recurrence::rYearlyMonth;
-            } else if (tmpStr.left(2) == QStringLiteral("YD")) {
-                type = Recurrence::rYearlyDay;
+        const int tmpStrLen = tmpStr.length();
+        if (tmpStrLen > 0) {
+            tmpStr = tmpStr.toUpper();
+            // first, read the type of the recurrence
+            recurrenceTypeAbbrLen = 1;
+            if (tmpStr.at(0) == QLatin1String("D")) {
+                recurrenceType = Recurrence::rDaily;
+            } else if (tmpStr.at(0) == QLatin1String("W")) {
+                recurrenceType = Recurrence::rWeekly;
+            } else if (tmpStrLen > 1) {
+                recurrenceTypeAbbrLen = 2;
+                if (tmpStr.leftRef(2) == QLatin1String("MP")) {
+                    recurrenceType = Recurrence::rMonthlyPos;
+                } else if (tmpStr.leftRef(2) == QLatin1String("MD")) {
+                    recurrenceType = Recurrence::rMonthlyDay;
+                } else if (tmpStr.leftRef(2) == QLatin1String("YM")) {
+                    recurrenceType = Recurrence::rYearlyMonth;
+                } else if (tmpStr.leftRef(2) == QLatin1String("YD")) {
+                    recurrenceType = Recurrence::rYearlyDay;
+                }
             }
         }
 
-        if (type != Recurrence::rNone) {
-
+        if (recurrenceType != Recurrence::rNone) {
             // Immediately after the type is the frequency
             int index = tmpStr.indexOf(QLatin1Char(' '));
             int last = tmpStr.lastIndexOf(QLatin1Char(' ')) + 1;   // find last entry
-            int rFreq = tmpStr.midRef(typelen, (index - 1)).toInt();
+            int rFreq = tmpStr.midRef(recurrenceTypeAbbrLen, (index - 1)).toInt();
             ++index; // advance to beginning of stuff after freq
 
             // Read the type-specific settings
-            switch (type) {
+            switch (recurrenceType) {
             case Recurrence::rDaily:
                 anEvent->recurrence()->setDaily(rFreq);
                 break;
@@ -690,7 +692,7 @@ Event::Ptr VCalFormat::VEventToEvent(VObject *vevent)
         anEvent->setOrganizer(QString::fromUtf8(s = fakeCString(vObjectUStringZValue(vo))));
         deleteStr(s);
     } else {
-        if (d->mCalendar->owner()->name() != QStringLiteral("Unknown Name")) {
+        if (d->mCalendar->owner().name() != QStringLiteral("Unknown Name")) {
             anEvent->setOrganizer(d->mCalendar->owner());
         }
     }
@@ -700,7 +702,7 @@ Event::Ptr VCalFormat::VEventToEvent(VObject *vevent)
     while (moreIteration(&voi)) {
         vo = nextVObject(&voi);
         if (strcmp(vObjectName(vo), VCAttendeeProp) == 0) {
-            Attendee::Ptr a;
+            Attendee a;
             VObject *vp = nullptr;
             s = fakeCString(vObjectUStringZValue(vo));
             QString tmpStr = QString::fromUtf8(s);
@@ -710,25 +712,23 @@ Event::Ptr VCalFormat::VEventToEvent(VObject *vevent)
             if ((emailPos1 = tmpStr.indexOf(QLatin1Char('<'))) > 0) {
                 // both email address and name
                 int emailPos2 = tmpStr.lastIndexOf(QLatin1Char('>'));
-                a = Attendee::Ptr(new Attendee(tmpStr.left(emailPos1 - 1),
-                                               tmpStr.mid(emailPos1 + 1,
-                                                       emailPos2 - (emailPos1 + 1))));
+                a = Attendee(tmpStr.left(emailPos1 - 1), tmpStr.mid(emailPos1 + 1, emailPos2 - (emailPos1 + 1)));
             } else if (tmpStr.indexOf(QLatin1Char('@')) > 0) {
                 // just an email address
-                a = Attendee::Ptr(new Attendee(QString(), tmpStr));
+                a = Attendee(QString(), tmpStr);
             } else {
                 // just a name
                 QString email = tmpStr.replace(QLatin1Char(' '), QLatin1Char('.'));
-                a = Attendee::Ptr(new Attendee(tmpStr, email));
+                a = Attendee(tmpStr, email);
             }
 
             // is there an RSVP property?
             if ((vp = isAPropertyOf(vo, VCRSVPProp)) != nullptr) {
-                a->setRSVP(vObjectStringZValue(vp));
+                a.setRSVP(vObjectStringZValue(vp));
             }
             // is there a status property?
             if ((vp = isAPropertyOf(vo, VCStatusProp)) != nullptr) {
-                a->setStatus(readStatus(vObjectStringZValue(vp)));
+                a.setStatus(readStatus(vObjectStringZValue(vp)));
             }
             // add the attendee
             anEvent->addAttendee(a);
@@ -781,42 +781,46 @@ Event::Ptr VCalFormat::VEventToEvent(VObject *vevent)
 
     ///////////////////////////////////////////////////////////////////////////
 
-    // repeat stuff
+    // recurrence stuff
     if ((vo = isAPropertyOf(vevent, VCRRuleProp)) != nullptr) {
+        uint recurrenceType = Recurrence::rNone;
+        int recurrenceTypeAbbrLen = 0;
+
         QString tmpStr = (QString::fromUtf8(s = fakeCString(vObjectUStringZValue(vo))));
         deleteStr(s);
         tmpStr = tmpStr.simplified();
-        tmpStr = tmpStr.toUpper();
-        // first, read the type of the recurrence
-        int typelen = 1;
-        uint type = Recurrence::rNone;
-        if (tmpStr.left(1) == QLatin1String("D")) {
-            type = Recurrence::rDaily;
-        } else if (tmpStr.left(1) == QLatin1String("W")) {
-            type = Recurrence::rWeekly;
-        } else {
-            typelen = 2;
-            if (tmpStr.left(2) == QLatin1String("MP")) {
-                type = Recurrence::rMonthlyPos;
-            } else if (tmpStr.left(2) == QLatin1String("MD")) {
-                type = Recurrence::rMonthlyDay;
-            } else if (tmpStr.left(2) == QLatin1String("YM")) {
-                type = Recurrence::rYearlyMonth;
-            } else if (tmpStr.left(2) == QLatin1String("YD")) {
-                type = Recurrence::rYearlyDay;
+        const int tmpStrLen = tmpStr.length();
+        if (tmpStrLen > 0) {
+            tmpStr = tmpStr.toUpper();
+            // first, read the type of the recurrence
+            recurrenceTypeAbbrLen = 1;
+            if (tmpStr.at(0) == QLatin1String("D")) {
+                recurrenceType = Recurrence::rDaily;
+            } else if (tmpStr.at(0) == QLatin1String("W")) {
+                recurrenceType = Recurrence::rWeekly;
+            } else if (tmpStrLen > 1){
+                recurrenceTypeAbbrLen = 2;
+                if (tmpStr.leftRef(2) == QLatin1String("MP")) {
+                    recurrenceType = Recurrence::rMonthlyPos;
+                } else if (tmpStr.leftRef(2) == QLatin1String("MD")) {
+                    recurrenceType = Recurrence::rMonthlyDay;
+                } else if (tmpStr.leftRef(2) == QLatin1String("YM")) {
+                    recurrenceType = Recurrence::rYearlyMonth;
+                } else if (tmpStr.leftRef(2) == QLatin1String("YD")) {
+                    recurrenceType = Recurrence::rYearlyDay;
+                }
             }
         }
 
-        if (type != Recurrence::rNone) {
-
+        if (recurrenceType != Recurrence::rNone) {
             // Immediately after the type is the frequency
             int index = tmpStr.indexOf(QLatin1Char(' '));
             int last = tmpStr.lastIndexOf(QLatin1Char(' ')) + 1;   // find last entry
-            int rFreq = tmpStr.midRef(typelen, (index - 1)).toInt();
+            int rFreq = tmpStr.midRef(recurrenceTypeAbbrLen, (index - 1)).toInt();
             ++index; // advance to beginning of stuff after freq
 
             // Read the type-specific settings
-            switch (type) {
+            switch (recurrenceType) {
             case Recurrence::rDaily:
                 anEvent->recurrence()->setDaily(rFreq);
                 break;
@@ -1056,7 +1060,7 @@ Event::Ptr VCalFormat::VEventToEvent(VObject *vevent)
         vo = nextVObject(&voi);
         if (strcmp(vObjectName(vo), VCAttachProp) == 0) {
             s = fakeCString(vObjectUStringZValue(vo));
-            anEvent->addAttachment(Attachment::Ptr(new Attachment(QString::fromUtf8(s))));
+            anEvent->addAttachment(Attachment(QString::fromUtf8(s)));
             deleteStr(s);
         }
     }
@@ -1209,20 +1213,15 @@ QString VCalFormat::parseDst(QByteArray &timezone) const
 
 QString VCalFormat::qDateToISO(const QDate &qd)
 {
-    QString tmpStr;
-
     if (!qd.isValid()) {
         return QString();
     }
 
-    tmpStr.sprintf("%.2d%.2d%.2d", qd.year(), qd.month(), qd.day());
-    return tmpStr;
+    return QString::asprintf("%.2d%.2d%.2d", qd.year(), qd.month(), qd.day());
 }
 
 QString VCalFormat::qDateTimeToISO(const QDateTime &dt, bool zulu)
 {
-    QString tmpStr;
-
     if (!dt.isValid()) {
         return QString();
     }
@@ -1233,10 +1232,10 @@ QString VCalFormat::qDateTimeToISO(const QDateTime &dt, bool zulu)
     } else {
         tmpDT = dt.toTimeZone(d->mCalendar->timeZone());
     }
-    tmpStr.sprintf("%.2d%.2d%.2dT%.2d%.2d%.2d",
-                   tmpDT.date().year(), tmpDT.date().month(),
-                   tmpDT.date().day(), tmpDT.time().hour(),
-                   tmpDT.time().minute(), tmpDT.time().second());
+    QString tmpStr = QString::asprintf("%.2d%.2d%.2dT%.2d%.2d%.2d",
+                                        tmpDT.date().year(), tmpDT.date().month(),
+                                        tmpDT.date().day(), tmpDT.time().hour(),
+                                        tmpDT.time().minute(), tmpDT.time().second());
     if (zulu || dt.timeZone() == QTimeZone::utc()) {
         tmpStr += QLatin1Char('Z');
     }
